pub struct Addrinfo { /* private fields */ }Implementations
Sourceimpl Addrinfo
impl Addrinfo
pub fn new( ai_flags: c_int, ai_family: c_int, ai_socktype: c_int, ai_protocol: c_int, ai_addrlen: socklen_t, ai_canonname: *mut c_char, ai_addr: &Sockaddr, ai_next: &Addrinfo, ) -> Result<Self, AeronCError>
Sourcepub fn new_zeroed_on_heap() -> Self
pub fn new_zeroed_on_heap() -> Self
creates zeroed struct where the underlying c struct is on the heap
Sourcepub fn new_zeroed_on_stack() -> Self
pub fn new_zeroed_on_stack() -> Self
creates zeroed struct where the underlying c struct is on the stack (Use with care)
pub fn ai_flags(&self) -> c_int
pub fn ai_family(&self) -> c_int
pub fn ai_socktype(&self) -> c_int
pub fn ai_protocol(&self) -> c_int
pub fn ai_addrlen(&self) -> socklen_t
pub fn ai_canonname(&self) -> &str
pub fn ai_addr(&self) -> Sockaddr
pub fn ai_next(&self) -> Addrinfo
pub fn get_inner(&self) -> *mut addrinfo
Sourcepub unsafe fn get_inner_mut(&self) -> &mut addrinfo
pub unsafe fn get_inner_mut(&self) -> &mut addrinfo
Mutable access to the underlying C struct, minted from &self: nothing
prevents two live &mut at once, so the caller must ensure exclusive
access for the lifetime of the returned reference.
Safety
No other reference (& or &mut) to the underlying struct may be
alive while the returned &mut is in use.
pub fn get_inner_ref(&self) -> &addrinfo
Sourceimpl Addrinfo
impl Addrinfo
Sourcepub fn clone_struct(&self) -> Self
pub fn clone_struct(&self) -> Self
Regular clone just increases the reference count of underlying count.
clone_struct shallow copies the content of the underlying struct on heap.
NOTE: if the struct has references to other structs these will not be copied
Must be only used on structs which has no init/clean up methods. So its dangerous to use with Aeron/AeronContext/AeronPublication/AeronSubscription More intended for AeronArchiveRecordingDescriptor (note strings will not work as its a shallow copy)