AeronAsyncExecutorTask

Struct AeronAsyncExecutorTask 

pub struct AeronAsyncExecutorTask { /* private fields */ }

Implementations

Source

impl AeronAsyncExecutorTask

pub fn new<AeronAsyncExecutorTaskCancelFuncHandlerImpl: AeronAsyncExecutorTaskCancelFuncCallback>( executor: &AeronAsyncExecutor, on_execute: aeron_async_executor_task_on_execute_func_t, on_complete: aeron_async_executor_task_on_complete_func_t, on_cancel: Option<&Handler<AeronAsyncExecutorTaskCancelFuncHandlerImpl>>, result: c_int, errcode: c_int, errmsg: [c_char; 8192], ) -> Result<Self, AeronCError>

pub fn new_zeroed_on_heap() -> Self

creates zeroed struct where the underlying c struct is on the heap

pub fn new_zeroed_on_stack() -> Self

creates zeroed struct where the underlying c struct is on the stack (Use with care)

pub fn executor(&self) -> AeronAsyncExecutor

pub fn on_execute(&self) -> aeron_async_executor_task_on_execute_func_t

pub fn on_complete(&self) -> aeron_async_executor_task_on_complete_func_t

pub fn on_cancel(&self) -> aeron_async_executor_task_on_cancel_func_t

pub fn clientd(&self) -> *mut c_void

pub fn result(&self) -> c_int

pub fn errcode(&self) -> c_int

pub fn errmsg(&self) -> [c_char; 8192]

pub fn do_complete(&self)

pub fn get_inner(&self) -> *mut aeron_async_executor_task_t

pub fn get_inner_mut(&self) -> &mut aeron_async_executor_task_t

pub fn get_inner_ref(&self) -> &aeron_async_executor_task_t

Source

impl AeronAsyncExecutorTask

pub fn clone_struct(&self) -> Self

Regular clone just increases the reference count of underlying count. clone_struct shallow copies the content of the underlying struct on heap.

NOTE: if the struct has references to other structs these will not be copied

Must be only used on structs which has no init/clean up methods. So its dangerous to use with Aeron/AeronContext/AeronPublication/AeronSubscription More intended for AeronArchiveRecordingDescriptor (note strings will not work as its a shallow copy)