pub struct AeronBlockingLinkedQueue { /* private fields */ }Implementations
Sourceimpl AeronBlockingLinkedQueue
impl AeronBlockingLinkedQueue
pub fn new( queue: AeronLinkedQueue, mutex: aeron_mutex_t, cv: aeron_cond_t, ) -> Result<Self, AeronCError>
Sourcepub fn new_zeroed_on_heap() -> Self
pub fn new_zeroed_on_heap() -> Self
creates zeroed struct where the underlying c struct is on the heap
Sourcepub fn new_zeroed_on_stack() -> Self
pub fn new_zeroed_on_stack() -> Self
creates zeroed struct where the underlying c struct is on the stack (Use with care)
pub fn queue(&self) -> AeronLinkedQueue
pub fn mutex(&self) -> aeron_mutex_t
pub fn cv(&self) -> aeron_cond_t
pub fn init(&self) -> Result<i32, AeronCError>
pub fn close(&self) -> Result<i32, AeronCError>
pub fn offer(&self, element: *mut c_void) -> Result<i32, AeronCError>
pub fn poll(&self) -> *mut c_void
pub fn take(&self) -> *mut c_void
pub fn is_empty(&self) -> bool
pub fn unblock(&self)
pub fn get_inner(&self) -> *mut aeron_blocking_linked_queue_t
pub fn get_inner_mut(&self) -> &mut aeron_blocking_linked_queue_t
pub fn get_inner_ref(&self) -> &aeron_blocking_linked_queue_t
Sourceimpl AeronBlockingLinkedQueue
impl AeronBlockingLinkedQueue
Sourcepub fn clone_struct(&self) -> Self
pub fn clone_struct(&self) -> Self
Regular clone just increases the reference count of underlying count.
clone_struct shallow copies the content of the underlying struct on heap.
NOTE: if the struct has references to other structs these will not be copied
Must be only used on structs which has no init/clean up methods. So its dangerous to use with Aeron/AeronContext/AeronPublication/AeronSubscription More intended for AeronArchiveRecordingDescriptor (note strings will not work as its a shallow copy)