pub struct AeronClient { /* private fields */ }Implementations
Sourceimpl AeronClient
impl AeronClient
pub fn new( reached_end_of_life: bool, closed_by_command: bool, client_id: i64, client_liveness_timeout_ms: i64, heartbeat_timestamp: AeronAtomicCounter, publication_links: aeron_client_stct_publication_link_stct, counter_links: aeron_client_stct_counter_link_stct, ) -> Result<Self, AeronCError>
Sourcepub fn new_zeroed_on_heap() -> Self
pub fn new_zeroed_on_heap() -> Self
creates zeroed struct where the underlying c struct is on the heap
Sourcepub fn new_zeroed_on_stack() -> Self
pub fn new_zeroed_on_stack() -> Self
creates zeroed struct where the underlying c struct is on the stack (Use with care)
pub fn reached_end_of_life(&self) -> bool
pub fn closed_by_command(&self) -> bool
pub fn client_id(&self) -> i64
pub fn client_liveness_timeout_ms(&self) -> i64
pub fn heartbeat_timestamp(&self) -> AeronAtomicCounter
pub fn publication_links(&self) -> aeron_client_stct_publication_link_stct
pub fn counter_links(&self) -> aeron_client_stct_counter_link_stct
pub fn free(arg1: *mut c_void) -> bool
pub fn get_inner(&self) -> *mut aeron_client_t
Sourcepub unsafe fn get_inner_mut(&self) -> &mut aeron_client_t
pub unsafe fn get_inner_mut(&self) -> &mut aeron_client_t
Mutable access to the underlying C struct, minted from &self: nothing
prevents two live &mut at once, so the caller must ensure exclusive
access for the lifetime of the returned reference.
Safety
No other reference (& or &mut) to the underlying struct may be
alive while the returned &mut is in use.
pub fn get_inner_ref(&self) -> &aeron_client_t
Sourceimpl AeronClient
impl AeronClient
Sourcepub fn clone_struct(&self) -> Self
pub fn clone_struct(&self) -> Self
Regular clone just increases the reference count of underlying count.
clone_struct shallow copies the content of the underlying struct on heap.
NOTE: if the struct has references to other structs these will not be copied
Must be only used on structs which has no init/clean up methods. So its dangerous to use with Aeron/AeronContext/AeronPublication/AeronSubscription More intended for AeronArchiveRecordingDescriptor (note strings will not work as its a shallow copy)