pub struct AeronDistinctErrorLog { /* private fields */ }Implementations
Sourceimpl AeronDistinctErrorLog
impl AeronDistinctErrorLog
pub fn new( buffer: *mut u8, observation_list: &AeronDistinctErrorLogObservationList, buffer_capacity: usize, next_offset: usize, clock: aeron_clock_func_t, mutex: aeron_mutex_t, ) -> Result<Self, AeronCError>
Sourcepub fn new_zeroed_on_heap() -> Self
pub fn new_zeroed_on_heap() -> Self
creates zeroed struct where the underlying c struct is on the heap
Sourcepub fn new_zeroed_on_stack() -> Self
pub fn new_zeroed_on_stack() -> Self
creates zeroed struct where the underlying c struct is on the stack (Use with care)
pub fn buffer(&self) -> *mut u8
pub fn observation_list(&self) -> AeronDistinctErrorLogObservationList
pub fn buffer_capacity(&self) -> usize
pub fn next_offset(&self) -> usize
pub fn clock(&self) -> aeron_clock_func_t
pub fn mutex(&self) -> aeron_mutex_t
pub fn init( &self, buffer: &mut [u8], clock: aeron_clock_func_t, ) -> Result<i32, AeronCError>
pub fn record( &self, error_code: c_int, description: &CStr, ) -> Result<i32, AeronCError>
pub fn num_observations(&self) -> usize
pub fn get_inner(&self) -> *mut aeron_distinct_error_log_t
Sourcepub unsafe fn get_inner_mut(&self) -> &mut aeron_distinct_error_log_t
pub unsafe fn get_inner_mut(&self) -> &mut aeron_distinct_error_log_t
Mutable access to the underlying C struct, minted from &self: nothing
prevents two live &mut at once, so the caller must ensure exclusive
access for the lifetime of the returned reference.
Safety
No other reference (& or &mut) to the underlying struct may be
alive while the returned &mut is in use.
pub fn get_inner_ref(&self) -> &aeron_distinct_error_log_t
Sourceimpl AeronDistinctErrorLog
impl AeronDistinctErrorLog
Sourcepub fn clone_struct(&self) -> Self
pub fn clone_struct(&self) -> Self
Regular clone just increases the reference count of underlying count.
clone_struct shallow copies the content of the underlying struct on heap.
NOTE: if the struct has references to other structs these will not be copied
Must be only used on structs which has no init/clean up methods. So its dangerous to use with Aeron/AeronContext/AeronPublication/AeronSubscription More intended for AeronArchiveRecordingDescriptor (note strings will not work as its a shallow copy)