pub struct AeronDriverConductorProxy { /* private fields */ }Implementations
Sourceimpl AeronDriverConductorProxy
impl AeronDriverConductorProxy
pub fn new( conductor: &AeronDriverConductor, command_queue: &AeronMpscRb, fail_counter: &mut i64, ) -> Result<Self, AeronCError>
Sourcepub fn new_zeroed_on_heap() -> Self
pub fn new_zeroed_on_heap() -> Self
creates zeroed struct where the underlying c struct is on the heap
Sourcepub fn new_zeroed_on_stack() -> Self
pub fn new_zeroed_on_stack() -> Self
creates zeroed struct where the underlying c struct is on the stack (Use with care)
pub fn conductor(&self) -> AeronDriverConductor
pub fn command_queue(&self) -> AeronMpscRb
pub fn fail_counter(&self) -> &mut i64
pub fn on_create_publication_image_cmd( &self, session_id: i32, stream_id: i32, initial_term_id: i32, active_term_id: i32, term_offset: i32, term_length: i32, mtu_length: i32, flags: u8, control_address: &SockaddrStorage, src_address: &SockaddrStorage, endpoint: *mut c_void, destination: *mut c_void, )
pub fn on_re_resolve_endpoint( &self, endpoint_name: &CStr, endpoint: *mut c_void, existing_addr: &SockaddrStorage, )
pub fn on_re_resolve_control( &self, endpoint_name: &CStr, endpoint: *mut c_void, destination: *mut c_void, existing_addr: &SockaddrStorage, )
pub fn on_delete_receive_destination( &self, endpoint: *mut c_void, destination: *mut c_void, channel: *mut c_void, )
pub fn on_delete_send_destination(&self, removed_uri: *mut c_void)
pub fn on_receive_endpoint_removed(&self, endpoint: *mut c_void)
pub fn on_response_setup( &self, response_correlation_id: i64, response_session_id: i32, )
pub fn on_response_connected(&self, response_correlation_id: i64)
pub fn on_release_resource( &self, managed_resource: *mut c_void, resource_type: aeron_driver_conductor_resource_type_t, )
pub fn on_publication_error( &self, registration_id: i64, destination_registration_id: i64, session_id: i32, stream_id: i32, receiver_id: i64, group_tag: i64, src_address: &SockaddrStorage, error_code: i32, error_length: i32, error_text: *const u8, )
pub fn get_inner(&self) -> *mut aeron_driver_conductor_proxy_t
Sourcepub unsafe fn get_inner_mut(&self) -> &mut aeron_driver_conductor_proxy_t
pub unsafe fn get_inner_mut(&self) -> &mut aeron_driver_conductor_proxy_t
Mutable access to the underlying C struct, minted from &self: nothing
prevents two live &mut at once, so the caller must ensure exclusive
access for the lifetime of the returned reference.
Safety
No other reference (& or &mut) to the underlying struct may be
alive while the returned &mut is in use.
pub fn get_inner_ref(&self) -> &aeron_driver_conductor_proxy_t
Sourceimpl AeronDriverConductorProxy
impl AeronDriverConductorProxy
Sourcepub fn clone_struct(&self) -> Self
pub fn clone_struct(&self) -> Self
Regular clone just increases the reference count of underlying count.
clone_struct shallow copies the content of the underlying struct on heap.
NOTE: if the struct has references to other structs these will not be copied
Must be only used on structs which has no init/clean up methods. So its dangerous to use with Aeron/AeronContext/AeronPublication/AeronSubscription More intended for AeronArchiveRecordingDescriptor (note strings will not work as its a shallow copy)