pub struct AeronDriverContext { /* private fields */ }Implementations
Sourceimpl AeronDriverContext
impl AeronDriverContext
Sourcepub fn new() -> Result<Self, AeronCError>
pub fn new() -> Result<Self, AeronCError>
Create a AeronDriverContext struct and initialize with default values.
Return
0 for success and -1 for error.
pub fn aeron_dir(&self) -> [c_char; 4096]
pub fn threading_mode(&self) -> aeron_threading_mode_t
pub fn receiver_group_consideration(&self) -> aeron_inferable_boolean_t
pub fn dirs_delete_on_start(&self) -> bool
pub fn dirs_delete_on_shutdown(&self) -> bool
pub fn warn_if_dirs_exist(&self) -> bool
pub fn term_buffer_sparse_file(&self) -> bool
pub fn perform_storage_checks(&self) -> bool
pub fn spies_simulate_connection(&self) -> bool
pub fn print_configuration_on_start(&self) -> bool
pub fn reliable_stream(&self) -> bool
pub fn tether_subscriptions(&self) -> bool
pub fn rejoin_stream(&self) -> bool
pub fn ats_enabled(&self) -> bool
pub fn connect_enabled(&self) -> bool
pub fn driver_timeout_ms(&self) -> u64
pub fn client_liveness_timeout_ns(&self) -> u64
pub fn publication_linger_timeout_ns(&self) -> u64
pub fn status_message_timeout_ns(&self) -> u64
pub fn image_liveness_timeout_ns(&self) -> u64
pub fn publication_unblock_timeout_ns(&self) -> u64
pub fn publication_connection_timeout_ns(&self) -> u64
pub fn timer_interval_ns(&self) -> u64
pub fn counter_free_to_reuse_ns(&self) -> u64
pub fn untethered_window_limit_timeout_ns(&self) -> u64
pub fn untethered_linger_timeout_ns(&self) -> i64
pub fn untethered_resting_timeout_ns(&self) -> u64
pub fn retransmit_unicast_delay_ns(&self) -> u64
pub fn retransmit_unicast_linger_ns(&self) -> u64
pub fn nak_unicast_delay_ns(&self) -> u64
pub fn nak_unicast_retry_delay_ratio(&self) -> u64
pub fn nak_multicast_max_backoff_ns(&self) -> u64
pub fn unicast_flow_control_rrwm(&self) -> usize
pub fn multicast_flow_control_rrwm(&self) -> usize
pub fn re_resolution_check_interval_ns(&self) -> u64
pub fn low_file_store_warning_threshold(&self) -> u64
pub fn to_driver_buffer_length(&self) -> usize
pub fn to_clients_buffer_length(&self) -> usize
pub fn counters_values_buffer_length(&self) -> usize
pub fn error_buffer_length(&self) -> usize
pub fn term_buffer_length(&self) -> usize
pub fn ipc_term_buffer_length(&self) -> usize
pub fn mtu_length(&self) -> usize
pub fn ipc_mtu_length(&self) -> usize
pub fn ipc_publication_window_length(&self) -> usize
pub fn publication_window_length(&self) -> usize
pub fn socket_rcvbuf(&self) -> usize
pub fn socket_sndbuf(&self) -> usize
pub fn send_to_sm_poll_ratio(&self) -> usize
pub fn initial_window_length(&self) -> usize
pub fn loss_report_length(&self) -> usize
pub fn file_page_size(&self) -> usize
pub fn nak_multicast_group_size(&self) -> usize
pub fn publication_reserved_session_id_low(&self) -> i32
pub fn publication_reserved_session_id_high(&self) -> i32
pub fn multicast_ttl(&self) -> u8
pub fn receiver_io_vector_capacity(&self) -> u32
pub fn sender_io_vector_capacity(&self) -> u32
pub fn network_publication_max_messages_per_send(&self) -> u32
pub fn resource_free_limit(&self) -> u32
pub fn max_resend(&self) -> u32
pub fn conductor_cpu_affinity_no(&self) -> i32
pub fn receiver_cpu_affinity_no(&self) -> i32
pub fn sender_cpu_affinity_no(&self) -> i32
pub fn native_resource_agent_cpu_affinity_no(&self) -> i32
pub fn stream_session_limit(&self) -> i32
pub fn cpuset_affinity(&self) -> bool
pub fn cpuset_warnings_as_errors(&self) -> bool
pub fn enable_experimental_features(&self) -> bool
pub fn receiver_group_tag(&self) -> aeron_driver_context_stct__bindgen_ty_1
pub fn flow_control(&self) -> aeron_driver_context_stct__bindgen_ty_2
pub fn cnc_map(&self) -> AeronMappedFile
pub fn loss_report(&self) -> AeronMappedFile
pub fn to_driver_buffer(&self) -> *mut u8
pub fn to_clients_buffer(&self) -> *mut u8
pub fn counters_values_buffer(&self) -> *mut u8
pub fn counters_metadata_buffer(&self) -> *mut u8
pub fn error_buffer(&self) -> *mut u8
pub fn nano_clock(&self) -> aeron_clock_func_t
pub fn epoch_clock(&self) -> aeron_clock_func_t
pub fn cached_clock(&self) -> AeronClockCache
pub fn sender_cached_clock(&self) -> AeronClockCache
pub fn receiver_cached_clock(&self) -> AeronClockCache
pub fn conductor_command_queue(&self) -> AeronMpscRb
pub fn sender_command_queue(&self) -> AeronSpscRb
pub fn receiver_command_queue(&self) -> AeronSpscRb
pub fn native_resource_agent_command_queue(&self) -> AeronSpscRb
pub fn agent_on_start_func(&self) -> aeron_agent_on_start_func_t
pub fn agent_on_start_state(&self) -> *mut c_void
pub fn agent_on_start_func_delegate(&self) -> aeron_agent_on_start_func_t
pub fn agent_on_start_state_delegate(&self) -> *mut c_void
pub fn conductor_idle_strategy_func(&self) -> aeron_idle_strategy_func_t
pub fn conductor_idle_strategy_state(&self) -> *mut c_void
pub fn conductor_idle_strategy_init_args(&self) -> &str
pub fn conductor_idle_strategy_name(&self) -> &str
pub fn sender_idle_strategy_func(&self) -> aeron_idle_strategy_func_t
pub fn sender_idle_strategy_state(&self) -> *mut c_void
pub fn sender_idle_strategy_init_args(&self) -> &str
pub fn sender_idle_strategy_name(&self) -> &str
pub fn receiver_idle_strategy_func(&self) -> aeron_idle_strategy_func_t
pub fn receiver_idle_strategy_state(&self) -> *mut c_void
pub fn receiver_idle_strategy_init_args(&self) -> &str
pub fn receiver_idle_strategy_name(&self) -> &str
pub fn native_resource_agent_idle_strategy_func( &self, ) -> aeron_idle_strategy_func_t
pub fn native_resource_agent_idle_strategy_state(&self) -> *mut c_void
pub fn native_resource_agent_idle_strategy_init_args(&self) -> &str
pub fn native_resource_agent_idle_strategy_name(&self) -> &str
pub fn usable_fs_space_func(&self) -> aeron_usable_fs_space_func_t
pub fn raw_log_map_func(&self) -> aeron_raw_log_map_func_t
pub fn raw_log_free_func(&self) -> aeron_raw_log_free_func_t
pub fn unicast_flow_control_supplier_func( &self, ) -> aeron_flow_control_strategy_supplier_func_t
pub fn multicast_flow_control_supplier_func( &self, ) -> aeron_flow_control_strategy_supplier_func_t
pub fn congestion_control_supplier_func( &self, ) -> aeron_congestion_control_strategy_supplier_func_t
pub fn conductor_proxy(&self) -> AeronDriverConductorProxy
pub fn native_resource_agent_proxy(&self) -> AeronDriverNativeResourceAgentProxy
pub fn sender_proxy(&self) -> AeronDriverSenderProxy
pub fn receiver_proxy(&self) -> AeronDriverReceiverProxy
pub fn counters_manager(&self) -> AeronCountersManager
pub fn system_counters(&self) -> AeronSystemCounters
pub fn error_log(&self) -> AeronDistinctErrorLog
pub fn log(&self) -> aeron_driver_context_stct__bindgen_ty_3
pub fn termination_validator_func( &self, ) -> aeron_driver_termination_validator_func_t
pub fn termination_validator_state(&self) -> *mut c_void
pub fn termination_hook_func(&self) -> aeron_driver_termination_hook_func_t
pub fn termination_hook_state(&self) -> *mut c_void
pub fn udp_channel_transport_bindings( &self, ) -> *mut aeron_udp_channel_transport_bindings_t
pub fn conductor_udp_channel_transport_bindings( &self, ) -> *mut aeron_udp_channel_transport_bindings_t
pub fn udp_channel_outgoing_interceptor_bindings( &self, ) -> AeronUdpChannelInterceptorBindings
pub fn udp_channel_incoming_interceptor_bindings( &self, ) -> AeronUdpChannelInterceptorBindings
pub fn next_receiver_id(&self) -> i64
pub fn unicast_delay_feedback_generator( &self, ) -> AeronFeedbackDelayGeneratorState
pub fn multicast_delay_feedback_generator( &self, ) -> AeronFeedbackDelayGeneratorState
pub fn resolver_name(&self) -> &str
pub fn resolver_interface(&self) -> &str
pub fn resolver_bootstrap_neighbor(&self) -> &str
pub fn resolver_neighbor_timeout_ns(&self) -> u64
pub fn resolver_self_resolution_interval_ns(&self) -> u64
pub fn resolver_neighbor_resolution_interval_ns(&self) -> u64
pub fn resolver_bootstrap_neighbor_resolution_interval_ns(&self) -> u64
pub fn name_resolver_init_args(&self) -> &str
pub fn name_resolver_supplier_func(&self) -> aeron_name_resolver_supplier_func_t
pub fn driver_name_resolver_bootstrap_resolver_supplier_func( &self, ) -> aeron_name_resolver_supplier_func_t
pub fn driver_name_resolver_boostrap_resolver_init_args(&self) -> &str
pub fn send_channel_loss_supplier_func( &self, ) -> aeron_send_channel_loss_supplier_func_t
pub fn send_channel_loss_supplier_clientd(&self) -> *mut c_void
pub fn receive_channel_loss_supplier_func( &self, ) -> aeron_receive_channel_loss_supplier_func_t
pub fn receive_channel_loss_supplier_clientd(&self) -> *mut c_void
pub fn conductor_duty_cycle_tracker(&self) -> AeronDutyCycleTracker
pub fn sender_duty_cycle_tracker(&self) -> AeronDutyCycleTracker
pub fn receiver_duty_cycle_tracker(&self) -> AeronDutyCycleTracker
pub fn name_resolver_time_tracker(&self) -> AeronDutyCycleTracker
pub fn conductor_duty_cycle_stall_tracker(&self) -> AeronDutyCycleStallTracker
pub fn sender_duty_cycle_stall_tracker(&self) -> AeronDutyCycleStallTracker
pub fn receiver_duty_cycle_stall_tracker(&self) -> AeronDutyCycleStallTracker
pub fn name_resolver_time_stall_tracker(&self) -> AeronDutyCycleStallTracker
pub fn sender_port_manager(&self) -> AeronPortManager
pub fn receiver_port_manager(&self) -> AeronPortManager
pub fn sender_wildcard_port_manager(&self) -> AeronWildcardPortManager
pub fn receiver_wildcard_port_manager(&self) -> AeronWildcardPortManager
pub fn dynamic_libs(&self) -> AeronDlLoadedLibsState
pub fn bindings_clientd_entries(&self) -> AeronDriverContextBindingsClientdEntry
pub fn num_bindings_clientd_entries(&self) -> usize
pub fn os_buffer_lengths(&self) -> aeron_driver_context_stct__bindgen_ty_4
pub fn set_dir(&self, value: &CStr) -> Result<i32, AeronCError>
pub fn get_dir(&self) -> &str
pub fn set_dir_warn_if_exists(&self, value: bool) -> Result<i32, AeronCError>
pub fn get_dir_warn_if_exists(&self) -> bool
pub fn set_threading_mode( &self, mode: aeron_threading_mode_t, ) -> Result<i32, AeronCError>
pub fn get_threading_mode(&self) -> aeron_threading_mode_t
pub fn set_dir_delete_on_start(&self, value: bool) -> Result<i32, AeronCError>
pub fn get_dir_delete_on_start(&self) -> bool
pub fn set_dir_delete_on_shutdown( &self, value: bool, ) -> Result<i32, AeronCError>
pub fn get_dir_delete_on_shutdown(&self) -> bool
pub fn set_to_conductor_buffer_length( &self, length: usize, ) -> Result<i32, AeronCError>
pub fn get_to_conductor_buffer_length(&self) -> usize
pub fn set_to_clients_buffer_length( &self, length: usize, ) -> Result<i32, AeronCError>
pub fn get_to_clients_buffer_length(&self) -> usize
pub fn set_counters_buffer_length( &self, length: usize, ) -> Result<i32, AeronCError>
pub fn get_counters_buffer_length(&self) -> usize
pub fn set_error_buffer_length(&self, length: usize) -> Result<i32, AeronCError>
pub fn get_error_buffer_length(&self) -> usize
pub fn set_client_liveness_timeout_ns( &self, value: u64, ) -> Result<i32, AeronCError>
pub fn get_client_liveness_timeout_ns(&self) -> u64
pub fn set_term_buffer_length(&self, value: usize) -> Result<i32, AeronCError>
pub fn get_term_buffer_length(&self) -> usize
pub fn set_ipc_term_buffer_length( &self, value: usize, ) -> Result<i32, AeronCError>
pub fn get_ipc_term_buffer_length(&self) -> usize
pub fn set_term_buffer_sparse_file( &self, value: bool, ) -> Result<i32, AeronCError>
pub fn get_term_buffer_sparse_file(&self) -> bool
pub fn set_perform_storage_checks( &self, value: bool, ) -> Result<i32, AeronCError>
pub fn get_perform_storage_checks(&self) -> bool
pub fn set_low_file_store_warning_threshold( &self, value: u64, ) -> Result<i32, AeronCError>
pub fn get_low_file_store_warning_threshold(&self) -> u64
pub fn set_spies_simulate_connection( &self, value: bool, ) -> Result<i32, AeronCError>
pub fn get_spies_simulate_connection(&self) -> bool
pub fn set_file_page_size(&self, value: usize) -> Result<i32, AeronCError>
pub fn get_file_page_size(&self) -> usize
pub fn set_mtu_length(&self, value: usize) -> Result<i32, AeronCError>
pub fn get_mtu_length(&self) -> usize
pub fn set_ipc_mtu_length(&self, value: usize) -> Result<i32, AeronCError>
pub fn get_ipc_mtu_length(&self) -> usize
pub fn set_ipc_publication_term_window_length( &self, value: usize, ) -> Result<i32, AeronCError>
pub fn get_ipc_publication_term_window_length(&self) -> usize
pub fn set_publication_term_window_length( &self, value: usize, ) -> Result<i32, AeronCError>
pub fn get_publication_term_window_length(&self) -> usize
pub fn set_publication_linger_timeout_ns( &self, value: u64, ) -> Result<i32, AeronCError>
pub fn get_publication_linger_timeout_ns(&self) -> u64
pub fn set_socket_so_rcvbuf(&self, value: usize) -> Result<i32, AeronCError>
pub fn get_socket_so_rcvbuf(&self) -> usize
pub fn set_socket_so_sndbuf(&self, value: usize) -> Result<i32, AeronCError>
pub fn get_socket_so_sndbuf(&self) -> usize
pub fn set_socket_multicast_ttl(&self, value: u8) -> Result<i32, AeronCError>
pub fn get_socket_multicast_ttl(&self) -> u8
pub fn set_send_to_status_poll_ratio( &self, value: usize, ) -> Result<i32, AeronCError>
pub fn get_send_to_status_poll_ratio(&self) -> usize
pub fn set_rcv_status_message_timeout_ns( &self, value: u64, ) -> Result<i32, AeronCError>
pub fn get_rcv_status_message_timeout_ns(&self) -> u64
pub fn set_multicast_flowcontrol_supplier( &self, value: aeron_flow_control_strategy_supplier_func_t, ) -> Result<i32, AeronCError>
pub fn get_multicast_flowcontrol_supplier( &self, ) -> aeron_flow_control_strategy_supplier_func_t
pub fn set_unicast_flowcontrol_supplier( &self, value: aeron_flow_control_strategy_supplier_func_t, ) -> Result<i32, AeronCError>
pub fn get_unicast_flowcontrol_supplier( &self, ) -> aeron_flow_control_strategy_supplier_func_t
pub fn set_image_liveness_timeout_ns( &self, value: u64, ) -> Result<i32, AeronCError>
pub fn get_image_liveness_timeout_ns(&self) -> u64
pub fn set_rcv_initial_window_length( &self, value: usize, ) -> Result<i32, AeronCError>
pub fn get_rcv_initial_window_length(&self) -> usize
pub fn set_congestioncontrol_supplier( &self, value: aeron_congestion_control_strategy_supplier_func_t, ) -> Result<i32, AeronCError>
pub fn get_congestioncontrol_supplier( &self, ) -> aeron_congestion_control_strategy_supplier_func_t
pub fn set_loss_report_buffer_length( &self, value: usize, ) -> Result<i32, AeronCError>
pub fn get_loss_report_buffer_length(&self) -> usize
pub fn set_publication_unblock_timeout_ns( &self, value: u64, ) -> Result<i32, AeronCError>
pub fn get_publication_unblock_timeout_ns(&self) -> u64
pub fn set_publication_connection_timeout_ns( &self, value: u64, ) -> Result<i32, AeronCError>
pub fn get_publication_connection_timeout_ns(&self) -> u64
pub fn set_timer_interval_ns(&self, value: u64) -> Result<i32, AeronCError>
pub fn get_timer_interval_ns(&self) -> u64
pub fn set_sender_idle_strategy(&self, value: &CStr) -> Result<i32, AeronCError>
pub fn get_sender_idle_strategy(&self) -> &str
pub fn set_conductor_idle_strategy( &self, value: &CStr, ) -> Result<i32, AeronCError>
pub fn get_conductor_idle_strategy(&self) -> &str
pub fn set_receiver_idle_strategy( &self, value: &CStr, ) -> Result<i32, AeronCError>
pub fn get_receiver_idle_strategy(&self) -> &str
pub fn set_sender_idle_strategy_init_args( &self, value: &CStr, ) -> Result<i32, AeronCError>
pub fn get_sender_idle_strategy_init_args(&self) -> &str
pub fn set_conductor_idle_strategy_init_args( &self, value: &CStr, ) -> Result<i32, AeronCError>
pub fn get_conductor_idle_strategy_init_args(&self) -> &str
pub fn set_receiver_idle_strategy_init_args( &self, value: &CStr, ) -> Result<i32, AeronCError>
pub fn get_receiver_idle_strategy_init_args(&self) -> &str
pub fn set_native_resource_agent_idle_strategy( &self, value: &CStr, ) -> Result<i32, AeronCError>
pub fn get_native_resource_agent_idle_strategy(&self) -> &str
pub fn set_native_resource_agent_idle_strategy_init_args( &self, value: &CStr, ) -> Result<i32, AeronCError>
pub fn get_native_resource_agent_idle_strategy_init_args(&self) -> &str
Sourcepub fn set_agent_on_start_function<AeronAgentStartFuncHandlerImpl: AeronAgentStartFuncCallback + 'static>(
&self,
value: Option<AeronAgentStartFuncHandlerImpl>,
) -> Result<Option<Handler<AeronAgentStartFuncHandlerImpl>>, AeronCError>
pub fn set_agent_on_start_function<AeronAgentStartFuncHandlerImpl: AeronAgentStartFuncCallback + 'static>( &self, value: Option<AeronAgentStartFuncHandlerImpl>, ) -> Result<Option<Handler<AeronAgentStartFuncHandlerImpl>>, AeronCError>
The callback is retained by the C client; this resource keeps it alive automatically.
Returns the created Handler for optional state access — safe to ignore. Closures with a matching signature are accepted directly.
pub fn get_agent_on_start_function(&self) -> aeron_agent_on_start_func_t
pub fn get_agent_on_start_state(&self) -> *mut c_void
pub fn set_counters_free_to_reuse_timeout_ns( &self, value: u64, ) -> Result<i32, AeronCError>
pub fn get_counters_free_to_reuse_timeout_ns(&self) -> u64
pub fn set_flow_control_receiver_timeout_ns( &self, value: u64, ) -> Result<i32, AeronCError>
pub fn get_flow_control_receiver_timeout_ns(&self) -> u64
pub fn set_flow_control_group_tag(&self, value: i64) -> Result<i32, AeronCError>
pub fn get_flow_control_group_tag(&self) -> i64
pub fn set_flow_control_group_min_size( &self, value: i32, ) -> Result<i32, AeronCError>
pub fn get_flow_control_group_min_size(&self) -> i32
pub fn set_receiver_group_tag( &self, is_present: bool, value: i64, ) -> Result<i32, AeronCError>
pub fn get_receiver_group_tag_is_present(&self) -> bool
pub fn get_receiver_group_tag_value(&self) -> i64
Sourcepub fn set_driver_termination_validator<AeronDriverTerminationValidatorFuncHandlerImpl: AeronDriverTerminationValidatorFuncCallback + 'static>(
&self,
value: Option<AeronDriverTerminationValidatorFuncHandlerImpl>,
) -> Result<Option<Handler<AeronDriverTerminationValidatorFuncHandlerImpl>>, AeronCError>
pub fn set_driver_termination_validator<AeronDriverTerminationValidatorFuncHandlerImpl: AeronDriverTerminationValidatorFuncCallback + 'static>( &self, value: Option<AeronDriverTerminationValidatorFuncHandlerImpl>, ) -> Result<Option<Handler<AeronDriverTerminationValidatorFuncHandlerImpl>>, AeronCError>
The callback is retained by the C client; this resource keeps it alive automatically.
Returns the created Handler for optional state access — safe to ignore. Closures with a matching signature are accepted directly.
pub fn get_driver_termination_validator( &self, ) -> aeron_driver_termination_validator_func_t
pub fn get_driver_termination_validator_state(&self) -> *mut c_void
Sourcepub fn set_driver_termination_hook<AeronDriverTerminationHookFuncHandlerImpl: AeronDriverTerminationHookFuncCallback + 'static>(
&self,
value: Option<AeronDriverTerminationHookFuncHandlerImpl>,
) -> Result<Option<Handler<AeronDriverTerminationHookFuncHandlerImpl>>, AeronCError>
pub fn set_driver_termination_hook<AeronDriverTerminationHookFuncHandlerImpl: AeronDriverTerminationHookFuncCallback + 'static>( &self, value: Option<AeronDriverTerminationHookFuncHandlerImpl>, ) -> Result<Option<Handler<AeronDriverTerminationHookFuncHandlerImpl>>, AeronCError>
The callback is retained by the C client; this resource keeps it alive automatically.
Returns the created Handler for optional state access — safe to ignore. Closures with a matching signature are accepted directly.
pub fn get_driver_termination_hook( &self, ) -> aeron_driver_termination_hook_func_t
pub fn get_driver_termination_hook_state(&self) -> *mut c_void
pub fn set_print_configuration(&self, value: bool) -> Result<i32, AeronCError>
pub fn get_print_configuration(&self) -> bool
pub fn set_reliable_stream(&self, value: bool) -> Result<i32, AeronCError>
pub fn get_reliable_stream(&self) -> bool
pub fn set_tether_subscriptions(&self, value: bool) -> Result<i32, AeronCError>
pub fn get_tether_subscriptions(&self) -> bool
pub fn set_untethered_window_limit_timeout_ns( &self, value: u64, ) -> Result<i32, AeronCError>
pub fn get_untethered_window_limit_timeout_ns(&self) -> u64
pub fn set_untethered_linger_timeout_ns( &self, value: u64, ) -> Result<i32, AeronCError>
pub fn get_untethered_linger_timeout_ns(&self) -> i64
pub fn set_untethered_resting_timeout_ns( &self, value: u64, ) -> Result<i32, AeronCError>
pub fn get_untethered_resting_timeout_ns(&self) -> u64
pub fn set_driver_timeout_ms(&self, value: u64) -> Result<i32, AeronCError>
pub fn get_driver_timeout_ms(&self) -> u64
pub fn set_nak_multicast_group_size( &self, value: usize, ) -> Result<i32, AeronCError>
pub fn get_nak_multicast_group_size(&self) -> usize
pub fn set_nak_multicast_max_backoff_ns( &self, value: u64, ) -> Result<i32, AeronCError>
pub fn get_nak_multicast_max_backoff_ns(&self) -> u64
pub fn set_nak_unicast_delay_ns(&self, value: u64) -> Result<i32, AeronCError>
pub fn get_nak_unicast_delay_ns(&self) -> u64
pub fn set_nak_unicast_retry_delay_ratio( &self, value: u64, ) -> Result<i32, AeronCError>
pub fn get_nak_unicast_retry_delay_ratio(&self) -> u64
pub fn set_max_resend(&self, value: u32) -> Result<i32, AeronCError>
pub fn get_max_resend(&self) -> u32
pub fn set_retransmit_unicast_delay_ns( &self, value: u64, ) -> Result<i32, AeronCError>
pub fn get_retransmit_unicast_delay_ns(&self) -> u64
pub fn set_retransmit_unicast_linger_ns( &self, value: u64, ) -> Result<i32, AeronCError>
pub fn get_retransmit_unicast_linger_ns(&self) -> u64
pub fn set_receiver_group_consideration( &self, value: aeron_inferable_boolean_t, ) -> Result<i32, AeronCError>
pub fn get_receiver_group_consideration(&self) -> aeron_inferable_boolean_t
pub fn set_rejoin_stream(&self, value: bool) -> Result<i32, AeronCError>
pub fn get_rejoin_stream(&self) -> bool
pub fn set_connect_enabled(&self, value: bool) -> Result<i32, AeronCError>
pub fn get_connect_enabled(&self) -> Result<i32, AeronCError>
pub fn set_udp_channel_transport_bindings( &self, value: *mut aeron_udp_channel_transport_bindings_t, ) -> Result<i32, AeronCError>
pub fn get_udp_channel_transport_bindings( &self, ) -> *mut aeron_udp_channel_transport_bindings_t
pub fn set_udp_channel_outgoing_interceptors( &self, value: &AeronUdpChannelInterceptorBindings, ) -> Result<i32, AeronCError>
pub fn get_udp_channel_outgoing_interceptors( &self, ) -> AeronUdpChannelInterceptorBindings
pub fn set_udp_channel_incoming_interceptors( &self, value: &AeronUdpChannelInterceptorBindings, ) -> Result<i32, AeronCError>
pub fn get_udp_channel_incoming_interceptors( &self, ) -> AeronUdpChannelInterceptorBindings
pub fn set_publication_reserved_session_id_low( &self, value: i32, ) -> Result<i32, AeronCError>
pub fn get_publication_reserved_session_id_low(&self) -> i32
pub fn set_publication_reserved_session_id_high( &self, value: i32, ) -> Result<i32, AeronCError>
pub fn get_publication_reserved_session_id_high(&self) -> i32
pub fn set_resolver_name(&self, value: &CStr) -> Result<i32, AeronCError>
pub fn get_resolver_name(&self) -> &str
pub fn set_resolver_interface(&self, value: &CStr) -> Result<i32, AeronCError>
pub fn get_resolver_interface(&self) -> &str
pub fn set_resolver_bootstrap_neighbor( &self, value: &CStr, ) -> Result<i32, AeronCError>
pub fn get_resolver_bootstrap_neighbor(&self) -> &str
pub fn set_name_resolver_supplier( &self, value: aeron_name_resolver_supplier_func_t, ) -> Result<i32, AeronCError>
pub fn get_name_resolver_supplier(&self) -> aeron_name_resolver_supplier_func_t
pub fn set_name_resolver_init_args( &self, value: &CStr, ) -> Result<i32, AeronCError>
pub fn get_name_resolver_init_args(&self) -> &str
pub fn set_resolver_neighbor_timeout_ns( &self, value: u64, ) -> Result<i32, AeronCError>
pub fn get_resolver_neighbor_timeout_ns(&self) -> u64
pub fn set_self_resolution_interval_ns( &self, value: u64, ) -> Result<i32, AeronCError>
pub fn get_self_resolution_interval_ns(&self) -> u64
pub fn set_resolver_neighbor_resolution_interval_ns( &self, value: u64, ) -> Result<i32, AeronCError>
pub fn get_resolver_neighbor_resolution_interval_ns(&self) -> u64
pub fn set_resolver_bootstrap_neighbor_resolution_interval_ns( &self, value: u64, ) -> Result<i32, AeronCError>
pub fn get_resolver_bootstrap_resolution_interval_ns(&self) -> u64
pub fn set_re_resolution_check_interval_ns( &self, value: u64, ) -> Result<i32, AeronCError>
pub fn get_re_resolution_check_interval_ns(&self) -> u64
pub fn set_conductor_duty_cycle_tracker( &self, value: &AeronDutyCycleTracker, ) -> Result<i32, AeronCError>
pub fn get_conductor_duty_cycle_tracker(&self) -> AeronDutyCycleTracker
pub fn set_sender_duty_cycle_tracker( &self, value: &AeronDutyCycleTracker, ) -> Result<i32, AeronCError>
pub fn get_sender_duty_cycle_tracker(&self) -> AeronDutyCycleTracker
pub fn set_receiver_duty_cycle_tracker( &self, value: &AeronDutyCycleTracker, ) -> Result<i32, AeronCError>
pub fn get_receiver_duty_cycle_tracker(&self) -> AeronDutyCycleTracker
pub fn set_name_resolver_time_tracker( &self, value: &AeronDutyCycleTracker, ) -> Result<i32, AeronCError>
pub fn get_name_resolver_time_tracker(&self) -> AeronDutyCycleTracker
pub fn set_sender_wildcard_port_range( &self, low_port: u16, high_port: u16, ) -> Result<i32, AeronCError>
pub fn get_sender_wildcard_port_range( &self, low_port: &mut u16, high_port: &mut u16, ) -> Result<i32, AeronCError>
pub fn set_receiver_wildcard_port_range( &self, low_port: u16, high_port: u16, ) -> Result<i32, AeronCError>
pub fn get_receiver_wildcard_port_range( &self, low_port: &mut u16, high_port: &mut u16, ) -> Result<i32, AeronCError>
pub fn set_sender_port_manager( &self, value: &AeronPortManager, ) -> Result<i32, AeronCError>
pub fn get_sender_port_manager(&self) -> AeronPortManager
pub fn set_receiver_port_manager( &self, value: &AeronPortManager, ) -> Result<i32, AeronCError>
pub fn get_receiver_port_manager(&self) -> AeronPortManager
pub fn set_conductor_cycle_threshold_ns(&self, value: u64) -> i64
pub fn get_conductor_cycle_threshold_ns(&self) -> i64
pub fn set_sender_cycle_threshold_ns(&self, value: u64) -> i64
pub fn get_sender_cycle_threshold_ns(&self) -> i64
pub fn set_receiver_cycle_threshold_ns(&self, value: u64) -> i64
pub fn get_receiver_cycle_threshold_ns(&self) -> i64
pub fn set_name_resolver_threshold_ns(&self, value: u64) -> i64
pub fn get_name_resolver_threshold_ns(&self) -> i64
pub fn set_receiver_io_vector_capacity( &self, value: u32, ) -> Result<i32, AeronCError>
pub fn get_receiver_io_vector_capacity(&self) -> u32
pub fn set_sender_io_vector_capacity( &self, value: u32, ) -> Result<i32, AeronCError>
pub fn get_sender_io_vector_capacity(&self) -> u32
pub fn set_network_publication_max_messages_per_send( &self, value: u32, ) -> Result<i32, AeronCError>
pub fn get_network_publication_max_messages_per_send(&self) -> u32
pub fn set_resource_free_limit(&self, value: u32) -> Result<i32, AeronCError>
pub fn get_resource_free_limit(&self) -> u32
pub fn set_conductor_cpu_affinity(&self, value: i32) -> Result<i32, AeronCError>
pub fn get_conductor_cpu_affinity(&self) -> i32
pub fn set_receiver_cpu_affinity(&self, value: i32) -> Result<i32, AeronCError>
pub fn get_receiver_cpu_affinity(&self) -> i32
pub fn set_sender_cpu_affinity(&self, value: i32) -> Result<i32, AeronCError>
pub fn get_sender_cpu_affinity(&self) -> i32
pub fn set_native_resource_agent_cpu_affinity( &self, value: i32, ) -> Result<i32, AeronCError>
pub fn get_native_resource_agent_cpu_affinity(&self) -> i32
pub fn set_cpuset_affinity(&self, value: bool) -> Result<i32, AeronCError>
pub fn get_cpuset_affinity(&self) -> bool
pub fn set_cpuset_warnings_as_errors( &self, value: bool, ) -> Result<i32, AeronCError>
pub fn get_cpuset_warnings_as_errors(&self) -> bool
pub fn set_enable_experimental_features( &self, value: bool, ) -> Result<i32, AeronCError>
pub fn get_enable_experimental_features(&self) -> Result<i32, AeronCError>
pub fn set_stream_session_limit(&self, value: i32) -> Result<i32, AeronCError>
pub fn get_stream_session_limit(&self) -> i32
pub fn print_configuration(&self)
pub fn aeron_driver_fill_cnc_metadata(&self)
pub fn aeron_driver_validate_unblock_timeout(&self) -> Result<i32, AeronCError>
pub fn aeron_driver_validate_untethered_timeouts( &self, ) -> Result<i32, AeronCError>
pub fn validate_mtu_length(mtu_length: u64) -> Result<i32, AeronCError>
pub fn aeron_cnc_length(&self) -> usize
pub fn run_storage_checks(&self, log_length: u64) -> Result<i32, AeronCError>
pub fn bindings_clientd_create_entries(&self) -> Result<i32, AeronCError>
pub fn bindings_clientd_delete_entries(&self) -> Result<i32, AeronCError>
pub fn bindings_clientd_find_first_free_index(&self) -> Result<i32, AeronCError>
pub fn bindings_clientd_find(&self, name: &CStr) -> Result<i32, AeronCError>
pub fn bindings_clientd_get_or_find_first_free_entry( &self, name: &CStr, ) -> AeronDriverContextBindingsClientdEntry
Sourcepub fn set_send_channel_loss_supplier<AeronSendChannelLossSupplierFuncHandlerImpl: AeronSendChannelLossSupplierFuncCallback + 'static>(
&self,
func: Option<AeronSendChannelLossSupplierFuncHandlerImpl>,
) -> Result<Option<Handler<AeronSendChannelLossSupplierFuncHandlerImpl>>, AeronCError>
pub fn set_send_channel_loss_supplier<AeronSendChannelLossSupplierFuncHandlerImpl: AeronSendChannelLossSupplierFuncCallback + 'static>( &self, func: Option<AeronSendChannelLossSupplierFuncHandlerImpl>, ) -> Result<Option<Handler<AeronSendChannelLossSupplierFuncHandlerImpl>>, AeronCError>
The callback is retained by the C client; this resource keeps it alive automatically.
Returns the created Handler for optional state access — safe to ignore. Closures with a matching signature are accepted directly.
Sourcepub fn set_receive_channel_loss_supplier<AeronReceiveChannelLossSupplierFuncHandlerImpl: AeronReceiveChannelLossSupplierFuncCallback + 'static>(
&self,
func: Option<AeronReceiveChannelLossSupplierFuncHandlerImpl>,
) -> Result<Option<Handler<AeronReceiveChannelLossSupplierFuncHandlerImpl>>, AeronCError>
pub fn set_receive_channel_loss_supplier<AeronReceiveChannelLossSupplierFuncHandlerImpl: AeronReceiveChannelLossSupplierFuncCallback + 'static>( &self, func: Option<AeronReceiveChannelLossSupplierFuncHandlerImpl>, ) -> Result<Option<Handler<AeronReceiveChannelLossSupplierFuncHandlerImpl>>, AeronCError>
The callback is retained by the C client; this resource keeps it alive automatically.
Returns the created Handler for optional state access — safe to ignore. Closures with a matching signature are accepted directly.
pub fn apply_cpuset_affinity( &self, cpus: *const c_int, cpu_count: c_int, ) -> Result<i32, AeronCError>
pub fn aeron_send_channel_endpoint_resolution_change( &self, endpoint: &AeronSendChannelEndpoint, endpoint_name: &CStr, new_addr: &SockaddrStorage, ) -> Result<i32, AeronCError>
pub fn aeron_driver_apply_cpuset_affinity(&self) -> Result<i32, AeronCError>
pub fn get_inner(&self) -> *mut aeron_driver_context_t
Sourcepub unsafe fn get_inner_mut(&self) -> &mut aeron_driver_context_t
pub unsafe fn get_inner_mut(&self) -> &mut aeron_driver_context_t
Mutable access to the underlying C struct, minted from &self: nothing
prevents two live &mut at once, so the caller must ensure exclusive
access for the lifetime of the returned reference.
Safety
No other reference (& or &mut) to the underlying struct may be
alive while the returned &mut is in use.
pub fn get_inner_ref(&self) -> &aeron_driver_context_t
Sourceimpl AeronDriverContext
impl AeronDriverContext
Sourcepub fn set_conductor_idle_strategy_kind(
&self,
kind: AeronIdleStrategyKind,
) -> Result<i32, AeronCError>
pub fn set_conductor_idle_strategy_kind( &self, kind: AeronIdleStrategyKind, ) -> Result<i32, AeronCError>
Typed variant of Self::set_conductor_idle_strategy.
Sourcepub fn set_sender_idle_strategy_kind(
&self,
kind: AeronIdleStrategyKind,
) -> Result<i32, AeronCError>
pub fn set_sender_idle_strategy_kind( &self, kind: AeronIdleStrategyKind, ) -> Result<i32, AeronCError>
Typed variant of Self::set_sender_idle_strategy.
Sourcepub fn set_receiver_idle_strategy_kind(
&self,
kind: AeronIdleStrategyKind,
) -> Result<i32, AeronCError>
pub fn set_receiver_idle_strategy_kind( &self, kind: AeronIdleStrategyKind, ) -> Result<i32, AeronCError>
Typed variant of Self::set_receiver_idle_strategy.
Typed variant of Self::set_sharednetwork_idle_strategy.
Typed variant of Self::set_shared_idle_strategy.