pub struct AeronDriverNativeResourceAgentProxy { /* private fields */ }Implementations
Sourceimpl AeronDriverNativeResourceAgentProxy
impl AeronDriverNativeResourceAgentProxy
pub fn new( native_resource_agent: &AeronDriverNativeResourceAgent, fail_counter: &mut i64, command_queue: &AeronSpscRb, ) -> Result<Self, AeronCError>
Sourcepub fn new_zeroed_on_heap() -> Self
pub fn new_zeroed_on_heap() -> Self
creates zeroed struct where the underlying c struct is on the heap
Sourcepub fn new_zeroed_on_stack() -> Self
pub fn new_zeroed_on_stack() -> Self
creates zeroed struct where the underlying c struct is on the stack (Use with care)
pub fn native_resource_agent(&self) -> AeronDriverNativeResourceAgent
pub fn fail_counter(&self) -> &mut i64
pub fn command_queue(&self) -> AeronSpscRb
pub fn resolve_address( &self, address_resolution_params: *mut aeron_name_resolver_async_resolve_t, result: &AeronDriverNativeResourceAgentCommandResult, )
pub fn parse_udp_channel( &self, async_parse: &AeronUdpChannelAsyncParse, result: &AeronDriverNativeResourceAgentCommandResult, )
pub fn free_log_buffer( &self, mapped_raw_log: &AeronMappedRawLog, log_file_name: &CStr, )
pub fn map_log_buffer( &self, log_file_name: &str, is_sparse: bool, result: &AeronDriverNativeResourceAgentCommandResult, )
pub fn get_inner(&self) -> *mut aeron_driver_native_resource_agent_proxy_t
Sourcepub unsafe fn get_inner_mut(
&self,
) -> &mut aeron_driver_native_resource_agent_proxy_t
pub unsafe fn get_inner_mut( &self, ) -> &mut aeron_driver_native_resource_agent_proxy_t
Mutable access to the underlying C struct, minted from &self: nothing
prevents two live &mut at once, so the caller must ensure exclusive
access for the lifetime of the returned reference.
Safety
No other reference (& or &mut) to the underlying struct may be
alive while the returned &mut is in use.
pub fn get_inner_ref(&self) -> &aeron_driver_native_resource_agent_proxy_t
Sourceimpl AeronDriverNativeResourceAgentProxy
impl AeronDriverNativeResourceAgentProxy
Sourcepub fn clone_struct(&self) -> Self
pub fn clone_struct(&self) -> Self
Regular clone just increases the reference count of underlying count.
clone_struct shallow copies the content of the underlying struct on heap.
NOTE: if the struct has references to other structs these will not be copied
Must be only used on structs which has no init/clean up methods. So its dangerous to use with Aeron/AeronContext/AeronPublication/AeronSubscription More intended for AeronArchiveRecordingDescriptor (note strings will not work as its a shallow copy)