pub struct AeronDriverNativeResourceAgentProxyCmdFreeLogBuffer { /* private fields */ }Implementations
Sourceimpl AeronDriverNativeResourceAgentProxyCmdFreeLogBuffer
impl AeronDriverNativeResourceAgentProxyCmdFreeLogBuffer
pub fn new( base: AeronDriverNativeResourceAgentProxyCmd, mapped_raw_log: &AeronMappedRawLog, log_file_name: &CStr, ) -> Result<Self, AeronCError>
Sourcepub fn new_zeroed_on_heap() -> Self
pub fn new_zeroed_on_heap() -> Self
creates zeroed struct where the underlying c struct is on the heap
Sourcepub fn new_zeroed_on_stack() -> Self
pub fn new_zeroed_on_stack() -> Self
creates zeroed struct where the underlying c struct is on the stack (Use with care)
pub fn base(&self) -> AeronDriverNativeResourceAgentProxyCmd
pub fn mapped_raw_log(&self) -> AeronMappedRawLog
pub fn log_file_name(&self) -> &str
pub fn get_inner( &self, ) -> *mut aeron_driver_native_resource_agent_proxy_cmd_free_log_buffer_t
Sourcepub unsafe fn get_inner_mut(
&self,
) -> &mut aeron_driver_native_resource_agent_proxy_cmd_free_log_buffer_t
pub unsafe fn get_inner_mut( &self, ) -> &mut aeron_driver_native_resource_agent_proxy_cmd_free_log_buffer_t
Mutable access to the underlying C struct, minted from &self: nothing
prevents two live &mut at once, so the caller must ensure exclusive
access for the lifetime of the returned reference.
Safety
No other reference (& or &mut) to the underlying struct may be
alive while the returned &mut is in use.
pub fn get_inner_ref( &self, ) -> &aeron_driver_native_resource_agent_proxy_cmd_free_log_buffer_t
Sourceimpl AeronDriverNativeResourceAgentProxyCmdFreeLogBuffer
impl AeronDriverNativeResourceAgentProxyCmdFreeLogBuffer
Sourcepub fn clone_struct(&self) -> Self
pub fn clone_struct(&self) -> Self
Regular clone just increases the reference count of underlying count.
clone_struct shallow copies the content of the underlying struct on heap.
NOTE: if the struct has references to other structs these will not be copied
Must be only used on structs which has no init/clean up methods. So its dangerous to use with Aeron/AeronContext/AeronPublication/AeronSubscription More intended for AeronArchiveRecordingDescriptor (note strings will not work as its a shallow copy)