pub struct AeronDriverReceiver { /* private fields */ }Implementations
Sourceimpl AeronDriverReceiver
impl AeronDriverReceiver
pub fn new( receiver_proxy: AeronDriverReceiverProxy, poller: aeron_udp_transport_poller_t, recv_buffers: aeron_driver_receiver_stct_aeron_driver_receiver_buffers_stct, images: aeron_driver_receiver_stct_aeron_driver_receiver_images_stct, pending_setups: aeron_driver_receiver_stct_aeron_driver_receiver_pending_setups_stct, data_paths: AeronUdpChannelDataPaths, context: &AeronDriverContext, poller_poll_func: aeron_udp_transport_poller_poll_func_t, recvmmsg_func: aeron_udp_channel_transport_recvmmsg_func_t, error_log: &AeronDistinctErrorLog, re_resolution_deadline_ns: i64, errors_counter: &mut i64, invalid_frames_counter: &mut i64, total_bytes_received_counter: &mut i64, resolution_changes_counter: &mut i64, ) -> Result<Self, AeronCError>
Sourcepub fn new_zeroed_on_heap() -> Self
pub fn new_zeroed_on_heap() -> Self
creates zeroed struct where the underlying c struct is on the heap
Sourcepub fn new_zeroed_on_stack() -> Self
pub fn new_zeroed_on_stack() -> Self
creates zeroed struct where the underlying c struct is on the stack (Use with care)
pub fn receiver_proxy(&self) -> AeronDriverReceiverProxy
pub fn poller(&self) -> aeron_udp_transport_poller_t
pub fn recv_buffers( &self, ) -> aeron_driver_receiver_stct_aeron_driver_receiver_buffers_stct
pub fn images( &self, ) -> aeron_driver_receiver_stct_aeron_driver_receiver_images_stct
pub fn pending_setups( &self, ) -> aeron_driver_receiver_stct_aeron_driver_receiver_pending_setups_stct
pub fn data_paths(&self) -> AeronUdpChannelDataPaths
pub fn context(&self) -> AeronDriverContext
pub fn poller_poll_func(&self) -> aeron_udp_transport_poller_poll_func_t
pub fn recvmmsg_func(&self) -> aeron_udp_channel_transport_recvmmsg_func_t
pub fn error_log(&self) -> AeronDistinctErrorLog
pub fn re_resolution_deadline_ns(&self) -> i64
pub fn errors_counter(&self) -> &mut i64
pub fn invalid_frames_counter(&self) -> &mut i64
pub fn total_bytes_received_counter(&self) -> &mut i64
pub fn resolution_changes_counter(&self) -> &mut i64
pub fn init( &self, context: &AeronDriverContext, system_counters: &AeronSystemCounters, error_log: &AeronDistinctErrorLog, ) -> Result<i32, AeronCError>
pub fn do_work(clientd: *mut c_void) -> Result<i32, AeronCError>
pub fn on_close(clientd: *mut c_void)
pub fn on_add_endpoint(clientd: *mut c_void, item: *mut c_void)
pub fn on_remove_endpoint(clientd: *mut c_void, item: *mut c_void)
pub fn on_add_subscription(clientd: *mut c_void, item: *mut c_void)
pub fn on_remove_subscription(clientd: *mut c_void, item: *mut c_void)
pub fn on_add_subscription_by_session(clientd: *mut c_void, item: *mut c_void)
pub fn on_request_setup(clientd: *mut c_void, item: *mut c_void)
pub fn on_remove_subscription_by_session( clientd: *mut c_void, item: *mut c_void, )
pub fn on_add_destination(clientd: *mut c_void, item: *mut c_void)
pub fn on_remove_destination(clientd: *mut c_void, item: *mut c_void)
pub fn on_add_publication_image(clientd: *mut c_void, item: *mut c_void)
pub fn on_remove_publication_image(clientd: *mut c_void, item: *mut c_void)
pub fn on_remove_matching_state(clientd: *mut c_void, item: *mut c_void)
pub fn on_resolution_change(clientd: *mut c_void, item: *mut c_void)
pub fn on_invalidate_image(clientd: *mut c_void, item: *mut c_void)
pub fn add_pending_setup( &self, endpoint: &AeronReceiveChannelEndpoint, destination: &AeronReceiveDestination, session_id: i32, stream_id: i32, control_addr: &SockaddrStorage, ) -> Result<i32, AeronCError>
pub fn get_inner(&self) -> *mut aeron_driver_receiver_t
Sourcepub unsafe fn get_inner_mut(&self) -> &mut aeron_driver_receiver_t
pub unsafe fn get_inner_mut(&self) -> &mut aeron_driver_receiver_t
Mutable access to the underlying C struct, minted from &self: nothing
prevents two live &mut at once, so the caller must ensure exclusive
access for the lifetime of the returned reference.
Safety
No other reference (& or &mut) to the underlying struct may be
alive while the returned &mut is in use.
pub fn get_inner_ref(&self) -> &aeron_driver_receiver_t
Sourceimpl AeronDriverReceiver
impl AeronDriverReceiver
Sourcepub fn clone_struct(&self) -> Self
pub fn clone_struct(&self) -> Self
Regular clone just increases the reference count of underlying count.
clone_struct shallow copies the content of the underlying struct on heap.
NOTE: if the struct has references to other structs these will not be copied
Must be only used on structs which has no init/clean up methods. So its dangerous to use with Aeron/AeronContext/AeronPublication/AeronSubscription More intended for AeronArchiveRecordingDescriptor (note strings will not work as its a shallow copy)