pub struct AeronDriverSenderProxy { /* private fields */ }Implementations
Sourceimpl AeronDriverSenderProxy
impl AeronDriverSenderProxy
pub fn new( sender: &AeronDriverSender, log: aeron_driver_sender_proxy_stct__bindgen_ty_1, command_queue: &AeronSpscRb, fail_counter: &mut i64, ) -> Result<Self, AeronCError>
Sourcepub fn new_zeroed_on_heap() -> Self
pub fn new_zeroed_on_heap() -> Self
creates zeroed struct where the underlying c struct is on the heap
Sourcepub fn new_zeroed_on_stack() -> Self
pub fn new_zeroed_on_stack() -> Self
creates zeroed struct where the underlying c struct is on the stack (Use with care)
pub fn sender(&self) -> AeronDriverSender
pub fn log(&self) -> aeron_driver_sender_proxy_stct__bindgen_ty_1
pub fn command_queue(&self) -> AeronSpscRb
pub fn fail_counter(&self) -> &mut i64
pub fn on_add_endpoint(&self, endpoint: &AeronSendChannelEndpoint)
pub fn on_remove_endpoint(&self, endpoint: &AeronSendChannelEndpoint)
pub fn on_add_publication(&self, publication: &AeronNetworkPublication)
pub fn on_remove_publication(&self, publication: &AeronNetworkPublication)
pub fn on_resolution_change( &self, endpoint_name: &CStr, endpoint: &AeronSendChannelEndpoint, new_addr: &SockaddrStorage, )
pub fn on_add_destination( &self, endpoint: &AeronSendChannelEndpoint, uri: &AeronUri, addr: &SockaddrStorage, destination_registration_id: i64, )
pub fn on_remove_destination( &self, endpoint: &AeronSendChannelEndpoint, addr: &SockaddrStorage, )
pub fn on_remove_destination_by_id( &self, endpoint: &AeronSendChannelEndpoint, destination_registration_id: i64, )
pub fn get_inner(&self) -> *mut aeron_driver_sender_proxy_t
Sourcepub unsafe fn get_inner_mut(&self) -> &mut aeron_driver_sender_proxy_t
pub unsafe fn get_inner_mut(&self) -> &mut aeron_driver_sender_proxy_t
Mutable access to the underlying C struct, minted from &self: nothing
prevents two live &mut at once, so the caller must ensure exclusive
access for the lifetime of the returned reference.
Safety
No other reference (& or &mut) to the underlying struct may be
alive while the returned &mut is in use.
pub fn get_inner_ref(&self) -> &aeron_driver_sender_proxy_t
Sourceimpl AeronDriverSenderProxy
impl AeronDriverSenderProxy
Sourcepub fn clone_struct(&self) -> Self
pub fn clone_struct(&self) -> Self
Regular clone just increases the reference count of underlying count.
clone_struct shallow copies the content of the underlying struct on heap.
NOTE: if the struct has references to other structs these will not be copied
Must be only used on structs which has no init/clean up methods. So its dangerous to use with Aeron/AeronContext/AeronPublication/AeronSubscription More intended for AeronArchiveRecordingDescriptor (note strings will not work as its a shallow copy)