pub struct AeronDriverUriPublicationParams { /* private fields */ }Implementations
Sourceimpl AeronDriverUriPublicationParams
impl AeronDriverUriPublicationParams
pub fn new( has_position: bool, is_sparse: bool, signal_eos: bool, spies_simulate_connection: bool, has_mtu_length: bool, mtu_length: usize, has_term_length: bool, term_length: usize, term_offset: usize, initial_term_id: i32, term_id: i32, linger_timeout_ns: u64, untethered_window_limit_timeout_ns: u64, untethered_linger_timeout_ns: i64, untethered_resting_timeout_ns: u64, has_session_id: bool, session_id: i32, entity_tag: i64, response_correlation_id: i64, has_max_resend: bool, max_resend: u32, has_publication_window_length: bool, publication_window_length: i32, is_response: bool, ) -> Result<Self, AeronCError>
Sourcepub fn new_zeroed_on_heap() -> Self
pub fn new_zeroed_on_heap() -> Self
creates zeroed struct where the underlying c struct is on the heap
Sourcepub fn new_zeroed_on_stack() -> Self
pub fn new_zeroed_on_stack() -> Self
creates zeroed struct where the underlying c struct is on the stack (Use with care)
pub fn has_position(&self) -> bool
pub fn is_sparse(&self) -> bool
pub fn signal_eos(&self) -> bool
pub fn spies_simulate_connection(&self) -> bool
pub fn has_mtu_length(&self) -> bool
pub fn mtu_length(&self) -> usize
pub fn has_term_length(&self) -> bool
pub fn term_length(&self) -> usize
pub fn term_offset(&self) -> usize
pub fn initial_term_id(&self) -> i32
pub fn term_id(&self) -> i32
pub fn linger_timeout_ns(&self) -> u64
pub fn untethered_window_limit_timeout_ns(&self) -> u64
pub fn untethered_linger_timeout_ns(&self) -> i64
pub fn untethered_resting_timeout_ns(&self) -> u64
pub fn has_session_id(&self) -> bool
pub fn session_id(&self) -> i32
pub fn entity_tag(&self) -> i64
pub fn response_correlation_id(&self) -> i64
pub fn has_max_resend(&self) -> bool
pub fn max_resend(&self) -> u32
pub fn has_publication_window_length(&self) -> bool
pub fn publication_window_length(&self) -> i32
pub fn is_response(&self) -> bool
pub fn aeron_publication_params_validate_mtu_for_sndbuf( &self, endpoint_socket_sndbuf: usize, channel_socket_sndbuf: usize, context_socket_sndbuf: usize, os_default_socket_sndbuf: usize, ) -> Result<i32, AeronCError>
pub fn get_inner(&self) -> *mut aeron_driver_uri_publication_params_t
Sourcepub unsafe fn get_inner_mut(&self) -> &mut aeron_driver_uri_publication_params_t
pub unsafe fn get_inner_mut(&self) -> &mut aeron_driver_uri_publication_params_t
Mutable access to the underlying C struct, minted from &self: nothing
prevents two live &mut at once, so the caller must ensure exclusive
access for the lifetime of the returned reference.
Safety
No other reference (& or &mut) to the underlying struct may be
alive while the returned &mut is in use.
pub fn get_inner_ref(&self) -> &aeron_driver_uri_publication_params_t
Sourceimpl AeronDriverUriPublicationParams
impl AeronDriverUriPublicationParams
Sourcepub fn clone_struct(&self) -> Self
pub fn clone_struct(&self) -> Self
Regular clone just increases the reference count of underlying count.
clone_struct shallow copies the content of the underlying struct on heap.
NOTE: if the struct has references to other structs these will not be copied
Must be only used on structs which has no init/clean up methods. So its dangerous to use with Aeron/AeronContext/AeronPublication/AeronSubscription More intended for AeronArchiveRecordingDescriptor (note strings will not work as its a shallow copy)