pub struct AeronDriverUriSubscriptionParams { /* private fields */ }Implementations
Sourceimpl AeronDriverUriSubscriptionParams
impl AeronDriverUriSubscriptionParams
pub fn new( is_reliable: bool, is_sparse: bool, is_tether: bool, is_rejoin: bool, has_session_id: bool, is_response: bool, group: aeron_inferable_boolean_t, session_id: i32, initial_window_length: usize, untethered_window_limit_timeout_ns: u64, untethered_linger_timeout_ns: i64, untethered_resting_timeout_ns: u64, ) -> Result<Self, AeronCError>
Sourcepub fn new_zeroed_on_heap() -> Self
pub fn new_zeroed_on_heap() -> Self
creates zeroed struct where the underlying c struct is on the heap
Sourcepub fn new_zeroed_on_stack() -> Self
pub fn new_zeroed_on_stack() -> Self
creates zeroed struct where the underlying c struct is on the stack (Use with care)
pub fn is_reliable(&self) -> bool
pub fn is_sparse(&self) -> bool
pub fn is_tether(&self) -> bool
pub fn is_rejoin(&self) -> bool
pub fn has_session_id(&self) -> bool
pub fn is_response(&self) -> bool
pub fn group(&self) -> aeron_inferable_boolean_t
pub fn session_id(&self) -> i32
pub fn initial_window_length(&self) -> usize
pub fn untethered_window_limit_timeout_ns(&self) -> u64
pub fn untethered_linger_timeout_ns(&self) -> i64
pub fn untethered_resting_timeout_ns(&self) -> u64
pub fn get_inner(&self) -> *mut aeron_driver_uri_subscription_params_t
Sourcepub unsafe fn get_inner_mut(
&self,
) -> &mut aeron_driver_uri_subscription_params_t
pub unsafe fn get_inner_mut( &self, ) -> &mut aeron_driver_uri_subscription_params_t
Mutable access to the underlying C struct, minted from &self: nothing
prevents two live &mut at once, so the caller must ensure exclusive
access for the lifetime of the returned reference.
Safety
No other reference (& or &mut) to the underlying struct may be
alive while the returned &mut is in use.
pub fn get_inner_ref(&self) -> &aeron_driver_uri_subscription_params_t
Sourceimpl AeronDriverUriSubscriptionParams
impl AeronDriverUriSubscriptionParams
Sourcepub fn clone_struct(&self) -> Self
pub fn clone_struct(&self) -> Self
Regular clone just increases the reference count of underlying count.
clone_struct shallow copies the content of the underlying struct on heap.
NOTE: if the struct has references to other structs these will not be copied
Must be only used on structs which has no init/clean up methods. So its dangerous to use with Aeron/AeronContext/AeronPublication/AeronSubscription More intended for AeronArchiveRecordingDescriptor (note strings will not work as its a shallow copy)