pub struct AeronDutyCycleStallTracker { /* private fields */ }Implementations
Sourceimpl AeronDutyCycleStallTracker
impl AeronDutyCycleStallTracker
pub fn new( tracker: aeron_duty_cycle_tracker_stct, lhs_padding: [c_char; 56], last_time_of_update_ns: i64, rhs_padding: [c_char; 56], cycle_threshold_ns: u64, max_cycle_time_counter: &mut i64, cycle_time_threshold_exceeded_counter: &mut i64, ) -> Result<Self, AeronCError>
Sourcepub fn new_zeroed_on_heap() -> Self
pub fn new_zeroed_on_heap() -> Self
creates zeroed struct where the underlying c struct is on the heap
Sourcepub fn new_zeroed_on_stack() -> Self
pub fn new_zeroed_on_stack() -> Self
creates zeroed struct where the underlying c struct is on the stack (Use with care)
pub fn tracker(&self) -> aeron_duty_cycle_tracker_stct
pub fn lhs_padding(&self) -> [c_char; 56]
pub fn last_time_of_update_ns(&self) -> i64
pub fn rhs_padding(&self) -> [c_char; 56]
pub fn cycle_threshold_ns(&self) -> u64
pub fn max_cycle_time_counter(&self) -> &mut i64
pub fn cycle_time_threshold_exceeded_counter(&self) -> &mut i64
pub fn get_inner(&self) -> *mut aeron_duty_cycle_stall_tracker_t
Sourcepub unsafe fn get_inner_mut(&self) -> &mut aeron_duty_cycle_stall_tracker_t
pub unsafe fn get_inner_mut(&self) -> &mut aeron_duty_cycle_stall_tracker_t
Mutable access to the underlying C struct, minted from &self: nothing
prevents two live &mut at once, so the caller must ensure exclusive
access for the lifetime of the returned reference.
Safety
No other reference (& or &mut) to the underlying struct may be
alive while the returned &mut is in use.
pub fn get_inner_ref(&self) -> &aeron_duty_cycle_stall_tracker_t
Sourceimpl AeronDutyCycleStallTracker
impl AeronDutyCycleStallTracker
Sourcepub fn clone_struct(&self) -> Self
pub fn clone_struct(&self) -> Self
Regular clone just increases the reference count of underlying count.
clone_struct shallow copies the content of the underlying struct on heap.
NOTE: if the struct has references to other structs these will not be copied
Must be only used on structs which has no init/clean up methods. So its dangerous to use with Aeron/AeronContext/AeronPublication/AeronSubscription More intended for AeronArchiveRecordingDescriptor (note strings will not work as its a shallow copy)