pub struct AeronDutyCycleTracker { /* private fields */ }Implementations
Sourceimpl AeronDutyCycleTracker
impl AeronDutyCycleTracker
pub fn new<AeronDutyCycleTrackerMeasureAndUpdateFuncHandlerImpl: AeronDutyCycleTrackerMeasureAndUpdateFuncCallback + 'static>( update: aeron_duty_cycle_tracker_update_func_t, measure_and_update: Option<&Handler<AeronDutyCycleTrackerMeasureAndUpdateFuncHandlerImpl>>, ) -> Result<Self, AeronCError>
Sourcepub fn new_zeroed_on_heap() -> Self
pub fn new_zeroed_on_heap() -> Self
creates zeroed struct where the underlying c struct is on the heap
Sourcepub fn new_zeroed_on_stack() -> Self
pub fn new_zeroed_on_stack() -> Self
creates zeroed struct where the underlying c struct is on the stack (Use with care)
pub fn update(&self) -> aeron_duty_cycle_tracker_update_func_t
pub fn measure_and_update( &self, ) -> aeron_duty_cycle_tracker_measure_and_update_func_t
pub fn state(&self) -> *mut c_void
pub fn get_inner(&self) -> *mut aeron_duty_cycle_tracker_t
Sourcepub unsafe fn get_inner_mut(&self) -> &mut aeron_duty_cycle_tracker_t
pub unsafe fn get_inner_mut(&self) -> &mut aeron_duty_cycle_tracker_t
Mutable access to the underlying C struct, minted from &self: nothing
prevents two live &mut at once, so the caller must ensure exclusive
access for the lifetime of the returned reference.
Safety
No other reference (& or &mut) to the underlying struct may be
alive while the returned &mut is in use.
pub fn get_inner_ref(&self) -> &aeron_duty_cycle_tracker_t
Sourceimpl AeronDutyCycleTracker
impl AeronDutyCycleTracker
Sourcepub fn clone_struct(&self) -> Self
pub fn clone_struct(&self) -> Self
Regular clone just increases the reference count of underlying count.
clone_struct shallow copies the content of the underlying struct on heap.
NOTE: if the struct has references to other structs these will not be copied
Must be only used on structs which has no init/clean up methods. So its dangerous to use with Aeron/AeronContext/AeronPublication/AeronSubscription More intended for AeronArchiveRecordingDescriptor (note strings will not work as its a shallow copy)