pub struct AeronError { /* private fields */ }Implementations
Sourceimpl AeronError
impl AeronError
pub fn new( frame_header: AeronFrameHeader, session_id: i32, stream_id: i32, receiver_id: i64, group_tag: i64, error_code: i32, error_length: i32, ) -> Result<Self, AeronCError>
Sourcepub fn new_zeroed_on_heap() -> Self
pub fn new_zeroed_on_heap() -> Self
creates zeroed struct where the underlying c struct is on the heap
Sourcepub fn new_zeroed_on_stack() -> Self
pub fn new_zeroed_on_stack() -> Self
creates zeroed struct where the underlying c struct is on the stack (Use with care)
pub fn frame_header(&self) -> AeronFrameHeader
pub fn session_id(&self) -> i32
pub fn stream_id(&self) -> i32
pub fn receiver_id(&self) -> i64
pub fn group_tag(&self) -> i64
pub fn error_code(&self) -> i32
pub fn error_length(&self) -> i32
Sourcepub fn code_str(errcode: c_int) -> &'static str
pub fn code_str(errcode: c_int) -> &'static str
SAFETY: this is static for performance reasons, so you should not store this without copying it!!
pub fn get_inner(&self) -> *mut aeron_error_t
pub fn get_inner_mut(&self) -> &mut aeron_error_t
pub fn get_inner_ref(&self) -> &aeron_error_t
Sourceimpl AeronError
impl AeronError
Sourcepub fn clone_struct(&self) -> Self
pub fn clone_struct(&self) -> Self
Regular clone just increases the reference count of underlying count.
clone_struct shallow copies the content of the underlying struct on heap.
NOTE: if the struct has references to other structs these will not be copied
Must be only used on structs which has no init/clean up methods. So its dangerous to use with Aeron/AeronContext/AeronPublication/AeronSubscription More intended for AeronArchiveRecordingDescriptor (note strings will not work as its a shallow copy)