pub struct AeronFeedbackDelayGeneratorState { /* private fields */ }Implementations
Sourceimpl AeronFeedbackDelayGeneratorState
impl AeronFeedbackDelayGeneratorState
pub fn new( static_delay: aeron_feedback_delay_generator_state_stct_static_delay_stct, optimal_delay: aeron_feedback_delay_generator_state_stct_optimal_delay_stct, delay_generator: aeron_feedback_delay_generator_func_t, ) -> Result<Self, AeronCError>
Sourcepub fn new_zeroed_on_heap() -> Self
pub fn new_zeroed_on_heap() -> Self
creates zeroed struct where the underlying c struct is on the heap
Sourcepub fn new_zeroed_on_stack() -> Self
pub fn new_zeroed_on_stack() -> Self
creates zeroed struct where the underlying c struct is on the stack (Use with care)
pub fn static_delay( &self, ) -> aeron_feedback_delay_generator_state_stct_static_delay_stct
pub fn optimal_delay( &self, ) -> aeron_feedback_delay_generator_state_stct_optimal_delay_stct
pub fn delay_generator(&self) -> aeron_feedback_delay_generator_func_t
pub fn aeron_feedback_delay_state_init( &self, delay_generator: aeron_feedback_delay_generator_func_t, delay_ns: i64, retry_ns: i64, multicast_group_size: usize, ) -> Result<i32, AeronCError>
pub fn aeron_loss_detector_nak_multicast_delay_generator( &self, retry: bool, ) -> i64
pub fn get_inner(&self) -> *mut aeron_feedback_delay_generator_state_t
Sourcepub unsafe fn get_inner_mut(
&self,
) -> &mut aeron_feedback_delay_generator_state_t
pub unsafe fn get_inner_mut( &self, ) -> &mut aeron_feedback_delay_generator_state_t
Mutable access to the underlying C struct, minted from &self: nothing
prevents two live &mut at once, so the caller must ensure exclusive
access for the lifetime of the returned reference.
Safety
No other reference (& or &mut) to the underlying struct may be
alive while the returned &mut is in use.
pub fn get_inner_ref(&self) -> &aeron_feedback_delay_generator_state_t
Sourceimpl AeronFeedbackDelayGeneratorState
impl AeronFeedbackDelayGeneratorState
Sourcepub fn clone_struct(&self) -> Self
pub fn clone_struct(&self) -> Self
Regular clone just increases the reference count of underlying count.
clone_struct shallow copies the content of the underlying struct on heap.
NOTE: if the struct has references to other structs these will not be copied
Must be only used on structs which has no init/clean up methods. So its dangerous to use with Aeron/AeronContext/AeronPublication/AeronSubscription More intended for AeronArchiveRecordingDescriptor (note strings will not work as its a shallow copy)