pub struct AeronFlowControlStrategy { /* private fields */ }Implementations
Sourceimpl AeronFlowControlStrategy
impl AeronFlowControlStrategy
Sourcepub fn new_zeroed_on_heap() -> Self
pub fn new_zeroed_on_heap() -> Self
creates zeroed struct where the underlying c struct is on the heap
Sourcepub fn new_zeroed_on_stack() -> Self
pub fn new_zeroed_on_stack() -> Self
creates zeroed struct where the underlying c struct is on the stack (Use with care)
pub fn on_status_message(&self) -> aeron_flow_control_strategy_on_sm_func_t
pub fn on_idle(&self) -> aeron_flow_control_strategy_on_idle_func_t
pub fn on_setup(&self) -> aeron_flow_control_strategy_on_setup_func_t
pub fn on_error(&self) -> aeron_flow_control_strategy_on_error_func_t
pub fn fini(&self) -> aeron_flow_control_strategy_fini_func_t
pub fn has_required_receivers( &self, ) -> aeron_flow_control_strategy_has_required_receivers_func_t
pub fn on_trigger_send_setup( &self, ) -> aeron_flow_control_strategy_on_trigger_send_setup_func_t
pub fn max_retransmission_length( &self, ) -> aeron_flow_control_strategy_max_retransmission_length_func_t
pub fn state(&self) -> *mut c_void
Sourcepub fn supplier_by_name(
name: &CStr,
) -> aeron_flow_control_strategy_supplier_func_t
pub fn supplier_by_name( name: &CStr, ) -> aeron_flow_control_strategy_supplier_func_t
Return a flow control strategy supplier function pointer associated with the given name. This only will find strategies built into the driver and will not try to dynamically load nor find any in the current executable.
Parameters
nameof the strategy
Return
function pointer to supplier associated with the name
pub fn has_required_receivers_default(&self) -> bool
pub fn supplier_load( strategy_name: &CStr, ) -> aeron_flow_control_strategy_supplier_func_t
pub fn aeron_tagged_flow_control_strategy_to_string( &self, buffer: &mut [u8], ) -> Result<i32, AeronCError>
pub fn aeron_tagged_flow_control_strategy_to_string_as_string( &self, max_length: usize, ) -> Result<String, AeronCError>
Sourcepub fn aeron_tagged_flow_control_strategy_to_string_into(
&self,
dst_truncate_to_capacity: &mut String,
) -> Result<i32, AeronCError>
pub fn aeron_tagged_flow_control_strategy_to_string_into( &self, dst_truncate_to_capacity: &mut String, ) -> Result<i32, AeronCError>
NOTE: allocation friendly method, the string capacity must be set as it will truncate string to capacity it will never grow the string. So if you pass String::new() it will write 0 chars
pub fn get_inner(&self) -> *mut aeron_flow_control_strategy_t
Sourcepub unsafe fn get_inner_mut(&self) -> &mut aeron_flow_control_strategy_t
pub unsafe fn get_inner_mut(&self) -> &mut aeron_flow_control_strategy_t
Mutable access to the underlying C struct, minted from &self: nothing
prevents two live &mut at once, so the caller must ensure exclusive
access for the lifetime of the returned reference.
Safety
No other reference (& or &mut) to the underlying struct may be
alive while the returned &mut is in use.
pub fn get_inner_ref(&self) -> &aeron_flow_control_strategy_t