pub struct AeronInt64CounterMap { /* private fields */ }Implementations
Sourceimpl AeronInt64CounterMap
impl AeronInt64CounterMap
pub fn new( entries: &mut i64, load_factor: f32, entries_length: usize, size: usize, resize_threshold: usize, initial_value: i64, ) -> Result<Self, AeronCError>
Sourcepub fn new_zeroed_on_heap() -> Self
pub fn new_zeroed_on_heap() -> Self
creates zeroed struct where the underlying c struct is on the heap
Sourcepub fn new_zeroed_on_stack() -> Self
pub fn new_zeroed_on_stack() -> Self
creates zeroed struct where the underlying c struct is on the stack (Use with care)
pub fn entries(&self) -> &mut i64
pub fn load_factor(&self) -> f32
pub fn entries_length(&self) -> usize
pub fn size(&self) -> usize
pub fn resize_threshold(&self) -> usize
pub fn initial_value(&self) -> i64
pub fn get_inner(&self) -> *mut aeron_int64_counter_map_t
Sourcepub unsafe fn get_inner_mut(&self) -> &mut aeron_int64_counter_map_t
pub unsafe fn get_inner_mut(&self) -> &mut aeron_int64_counter_map_t
Mutable access to the underlying C struct, minted from &self: nothing
prevents two live &mut at once, so the caller must ensure exclusive
access for the lifetime of the returned reference.
Safety
No other reference (& or &mut) to the underlying struct may be
alive while the returned &mut is in use.
pub fn get_inner_ref(&self) -> &aeron_int64_counter_map_t
Sourceimpl AeronInt64CounterMap
impl AeronInt64CounterMap
Sourcepub fn clone_struct(&self) -> Self
pub fn clone_struct(&self) -> Self
Regular clone just increases the reference count of underlying count.
clone_struct shallow copies the content of the underlying struct on heap.
NOTE: if the struct has references to other structs these will not be copied
Must be only used on structs which has no init/clean up methods. So its dangerous to use with Aeron/AeronContext/AeronPublication/AeronSubscription More intended for AeronArchiveRecordingDescriptor (note strings will not work as its a shallow copy)