pub struct AeronLinkedQueue { /* private fields */ }Implementations
Sourceimpl AeronLinkedQueue
impl AeronLinkedQueue
pub fn new( head: &AeronLinkedQueueNode, tail: &AeronLinkedQueueNode, ) -> Result<Self, AeronCError>
Sourcepub fn new_zeroed_on_heap() -> Self
pub fn new_zeroed_on_heap() -> Self
creates zeroed struct where the underlying c struct is on the heap
Sourcepub fn new_zeroed_on_stack() -> Self
pub fn new_zeroed_on_stack() -> Self
creates zeroed struct where the underlying c struct is on the stack (Use with care)
pub fn head(&self) -> AeronLinkedQueueNode
pub fn tail(&self) -> AeronLinkedQueueNode
pub fn init(&self) -> Result<i32, AeronCError>
pub fn close(&self) -> Result<i32, AeronCError>
pub fn offer(&self, element: *mut c_void) -> Result<i32, AeronCError>
pub fn peek(&self) -> *mut c_void
pub fn poll(&self) -> *mut c_void
pub fn is_empty(&self) -> bool
pub fn get_inner(&self) -> *mut aeron_linked_queue_t
pub fn get_inner_mut(&self) -> &mut aeron_linked_queue_t
pub fn get_inner_ref(&self) -> &aeron_linked_queue_t
Sourceimpl AeronLinkedQueue
impl AeronLinkedQueue
Sourcepub fn clone_struct(&self) -> Self
pub fn clone_struct(&self) -> Self
Regular clone just increases the reference count of underlying count.
clone_struct shallow copies the content of the underlying struct on heap.
NOTE: if the struct has references to other structs these will not be copied
Must be only used on structs which has no init/clean up methods. So its dangerous to use with Aeron/AeronContext/AeronPublication/AeronSubscription More intended for AeronArchiveRecordingDescriptor (note strings will not work as its a shallow copy)