pub struct AeronNamedInterface { /* private fields */ }Implementations
Sourceimpl AeronNamedInterface
impl AeronNamedInterface
pub fn new(name: [c_char; 16], port: c_int) -> Result<Self, AeronCError>
Sourcepub fn new_zeroed_on_heap() -> Self
pub fn new_zeroed_on_heap() -> Self
creates zeroed struct where the underlying c struct is on the heap
Sourcepub fn new_zeroed_on_stack() -> Self
pub fn new_zeroed_on_stack() -> Self
creates zeroed struct where the underlying c struct is on the stack (Use with care)
pub fn name(&self) -> [c_char; 16]
pub fn port(&self) -> c_int
pub fn get_inner(&self) -> *mut aeron_named_interface_t
pub fn get_inner_mut(&self) -> &mut aeron_named_interface_t
pub fn get_inner_ref(&self) -> &aeron_named_interface_t
Sourceimpl AeronNamedInterface
impl AeronNamedInterface
Sourcepub fn clone_struct(&self) -> Self
pub fn clone_struct(&self) -> Self
Regular clone just increases the reference count of underlying count.
clone_struct shallow copies the content of the underlying struct on heap.
NOTE: if the struct has references to other structs these will not be copied
Must be only used on structs which has no init/clean up methods. So its dangerous to use with Aeron/AeronContext/AeronPublication/AeronSubscription More intended for AeronArchiveRecordingDescriptor (note strings will not work as its a shallow copy)