pub struct AeronSpscConcurrentArrayQueue { /* private fields */ }Implementations
Sourceimpl AeronSpscConcurrentArrayQueue
impl AeronSpscConcurrentArrayQueue
pub fn new( padding1: [i8; 64], producer: aeron_spsc_concurrent_array_queue_stct__bindgen_ty_1, padding2: [i8; 64], consumer: aeron_spsc_concurrent_array_queue_stct__bindgen_ty_2, padding3: [i8; 64], capacity: usize, mask: usize, buffer: *mut *mut c_void, ) -> Result<Self, AeronCError>
Sourcepub fn new_zeroed_on_heap() -> Self
pub fn new_zeroed_on_heap() -> Self
creates zeroed struct where the underlying c struct is on the heap
Sourcepub fn new_zeroed_on_stack() -> Self
pub fn new_zeroed_on_stack() -> Self
creates zeroed struct where the underlying c struct is on the stack (Use with care)
pub fn padding1(&self) -> [i8; 64]
pub fn producer(&self) -> aeron_spsc_concurrent_array_queue_stct__bindgen_ty_1
pub fn padding2(&self) -> [i8; 64]
pub fn consumer(&self) -> aeron_spsc_concurrent_array_queue_stct__bindgen_ty_2
pub fn padding3(&self) -> [i8; 64]
pub fn capacity(&self) -> usize
pub fn mask(&self) -> usize
pub fn buffer(&self) -> *mut *mut c_void
pub fn init(&self, length: usize) -> Result<i32, AeronCError>
pub fn get_inner(&self) -> *mut aeron_spsc_concurrent_array_queue_t
Sourcepub unsafe fn get_inner_mut(&self) -> &mut aeron_spsc_concurrent_array_queue_t
pub unsafe fn get_inner_mut(&self) -> &mut aeron_spsc_concurrent_array_queue_t
Mutable access to the underlying C struct, minted from &self: nothing
prevents two live &mut at once, so the caller must ensure exclusive
access for the lifetime of the returned reference.
Safety
No other reference (& or &mut) to the underlying struct may be
alive while the returned &mut is in use.
pub fn get_inner_ref(&self) -> &aeron_spsc_concurrent_array_queue_t
Sourceimpl AeronSpscConcurrentArrayQueue
impl AeronSpscConcurrentArrayQueue
Sourcepub fn clone_struct(&self) -> Self
pub fn clone_struct(&self) -> Self
Regular clone just increases the reference count of underlying count.
clone_struct shallow copies the content of the underlying struct on heap.
NOTE: if the struct has references to other structs these will not be copied
Must be only used on structs which has no init/clean up methods. So its dangerous to use with Aeron/AeronContext/AeronPublication/AeronSubscription More intended for AeronArchiveRecordingDescriptor (note strings will not work as its a shallow copy)