pub struct AeronSubscriptionLink { /* private fields */ }Implementations
Sourceimpl AeronSubscriptionLink
impl AeronSubscriptionLink
pub fn new( channel: [c_char; 4096], is_tether: bool, is_sparse: bool, is_reliable: bool, is_rejoin: bool, has_session_id: bool, is_response: bool, group: aeron_inferable_boolean_t, stream_id: i32, session_id: i32, channel_length: i32, registration_id: i64, client_id: i64, endpoint: &AeronReceiveChannelEndpoint, spy_channel: &AeronUdpChannel, subscribable_list: aeron_subscription_link_stct_subscribable_list_stct, ) -> Result<Self, AeronCError>
Sourcepub fn new_zeroed_on_heap() -> Self
pub fn new_zeroed_on_heap() -> Self
creates zeroed struct where the underlying c struct is on the heap
Sourcepub fn new_zeroed_on_stack() -> Self
pub fn new_zeroed_on_stack() -> Self
creates zeroed struct where the underlying c struct is on the stack (Use with care)
pub fn channel(&self) -> [c_char; 4096]
pub fn is_tether(&self) -> bool
pub fn is_sparse(&self) -> bool
pub fn is_reliable(&self) -> bool
pub fn is_rejoin(&self) -> bool
pub fn has_session_id(&self) -> bool
pub fn is_response(&self) -> bool
pub fn group(&self) -> aeron_inferable_boolean_t
pub fn stream_id(&self) -> i32
pub fn session_id(&self) -> i32
pub fn channel_length(&self) -> i32
pub fn registration_id(&self) -> i64
pub fn client_id(&self) -> i64
pub fn endpoint(&self) -> AeronReceiveChannelEndpoint
pub fn spy_channel(&self) -> AeronUdpChannel
pub fn subscribable_list( &self, ) -> aeron_subscription_link_stct_subscribable_list_stct
pub fn aeron_driver_conductor_unlink_subscribable( &self, subscribable: &AeronSubscribable, )
pub fn get_inner(&self) -> *mut aeron_subscription_link_t
Sourcepub unsafe fn get_inner_mut(&self) -> &mut aeron_subscription_link_t
pub unsafe fn get_inner_mut(&self) -> &mut aeron_subscription_link_t
Mutable access to the underlying C struct, minted from &self: nothing
prevents two live &mut at once, so the caller must ensure exclusive
access for the lifetime of the returned reference.
Safety
No other reference (& or &mut) to the underlying struct may be
alive while the returned &mut is in use.
pub fn get_inner_ref(&self) -> &aeron_subscription_link_t
Sourceimpl AeronSubscriptionLink
impl AeronSubscriptionLink
Sourcepub fn clone_struct(&self) -> Self
pub fn clone_struct(&self) -> Self
Regular clone just increases the reference count of underlying count.
clone_struct shallow copies the content of the underlying struct on heap.
NOTE: if the struct has references to other structs these will not be copied
Must be only used on structs which has no init/clean up methods. So its dangerous to use with Aeron/AeronContext/AeronPublication/AeronSubscription More intended for AeronArchiveRecordingDescriptor (note strings will not work as its a shallow copy)