pub struct AeronTetherablePosition { /* private fields */ }Implementations
Sourceimpl AeronTetherablePosition
impl AeronTetherablePosition
pub fn new( value_addr: &mut i64, subscription_registration_id: i64, time_of_last_update_ns: i64, state: aeron_subscription_tether_state_t, counter_id: i32, is_tether: bool, is_rejoin: bool, ) -> Result<Self, AeronCError>
Sourcepub fn new_zeroed_on_heap() -> Self
pub fn new_zeroed_on_heap() -> Self
creates zeroed struct where the underlying c struct is on the heap
Sourcepub fn new_zeroed_on_stack() -> Self
pub fn new_zeroed_on_stack() -> Self
creates zeroed struct where the underlying c struct is on the stack (Use with care)
pub fn value_addr(&self) -> &mut i64
pub fn subscription_registration_id(&self) -> i64
pub fn time_of_last_update_ns(&self) -> i64
pub fn state(&self) -> aeron_subscription_tether_state_t
pub fn counter_id(&self) -> i32
pub fn is_tether(&self) -> bool
pub fn is_rejoin(&self) -> bool
pub fn get_inner(&self) -> *mut aeron_tetherable_position_t
Sourcepub unsafe fn get_inner_mut(&self) -> &mut aeron_tetherable_position_t
pub unsafe fn get_inner_mut(&self) -> &mut aeron_tetherable_position_t
Mutable access to the underlying C struct, minted from &self: nothing
prevents two live &mut at once, so the caller must ensure exclusive
access for the lifetime of the returned reference.
Safety
No other reference (& or &mut) to the underlying struct may be
alive while the returned &mut is in use.
pub fn get_inner_ref(&self) -> &aeron_tetherable_position_t
Sourceimpl AeronTetherablePosition
impl AeronTetherablePosition
Sourcepub fn clone_struct(&self) -> Self
pub fn clone_struct(&self) -> Self
Regular clone just increases the reference count of underlying count.
clone_struct shallow copies the content of the underlying struct on heap.
NOTE: if the struct has references to other structs these will not be copied
Must be only used on structs which has no init/clean up methods. So its dangerous to use with Aeron/AeronContext/AeronPublication/AeronSubscription More intended for AeronArchiveRecordingDescriptor (note strings will not work as its a shallow copy)