pub struct AeronUdpChannelIncomingInterceptor { /* private fields */ }Implementations
Sourceimpl AeronUdpChannelIncomingInterceptor
impl AeronUdpChannelIncomingInterceptor
pub fn new( interceptor_state: *mut c_void, incoming_func: aeron_udp_channel_interceptor_incoming_func_t, close_func: aeron_udp_channel_interceptor_close_func_t, incoming_transport_notification_func: aeron_udp_channel_interceptor_transport_notification_func_t, incoming_publication_notification_func: aeron_udp_channel_interceptor_publication_notification_func_t, incoming_image_notification_func: aeron_udp_channel_interceptor_image_notification_func_t, next_interceptor: &AeronUdpChannelIncomingInterceptor, ) -> Result<Self, AeronCError>
Sourcepub fn new_zeroed_on_heap() -> Self
pub fn new_zeroed_on_heap() -> Self
creates zeroed struct where the underlying c struct is on the heap
Sourcepub fn new_zeroed_on_stack() -> Self
pub fn new_zeroed_on_stack() -> Self
creates zeroed struct where the underlying c struct is on the stack (Use with care)
pub fn interceptor_state(&self) -> *mut c_void
pub fn incoming_func(&self) -> aeron_udp_channel_interceptor_incoming_func_t
pub fn close_func(&self) -> aeron_udp_channel_interceptor_close_func_t
pub fn incoming_transport_notification_func( &self, ) -> aeron_udp_channel_interceptor_transport_notification_func_t
pub fn incoming_publication_notification_func( &self, ) -> aeron_udp_channel_interceptor_publication_notification_func_t
pub fn incoming_image_notification_func( &self, ) -> aeron_udp_channel_interceptor_image_notification_func_t
pub fn next_interceptor(&self) -> AeronUdpChannelIncomingInterceptor
pub fn get_inner(&self) -> *mut aeron_udp_channel_incoming_interceptor_t
Sourcepub unsafe fn get_inner_mut(
&self,
) -> &mut aeron_udp_channel_incoming_interceptor_t
pub unsafe fn get_inner_mut( &self, ) -> &mut aeron_udp_channel_incoming_interceptor_t
Mutable access to the underlying C struct, minted from &self: nothing
prevents two live &mut at once, so the caller must ensure exclusive
access for the lifetime of the returned reference.
Safety
No other reference (& or &mut) to the underlying struct may be
alive while the returned &mut is in use.
pub fn get_inner_ref(&self) -> &aeron_udp_channel_incoming_interceptor_t
Sourceimpl AeronUdpChannelIncomingInterceptor
impl AeronUdpChannelIncomingInterceptor
Sourcepub fn clone_struct(&self) -> Self
pub fn clone_struct(&self) -> Self
Regular clone just increases the reference count of underlying count.
clone_struct shallow copies the content of the underlying struct on heap.
NOTE: if the struct has references to other structs these will not be copied
Must be only used on structs which has no init/clean up methods. So its dangerous to use with Aeron/AeronContext/AeronPublication/AeronSubscription More intended for AeronArchiveRecordingDescriptor (note strings will not work as its a shallow copy)