pub struct AeronUdpChannelInterceptorBindings { /* private fields */ }Implementations
Sourceimpl AeronUdpChannelInterceptorBindings
impl AeronUdpChannelInterceptorBindings
pub fn new( outgoing_init_func: aeron_udp_channel_interceptor_init_func_t, incoming_init_func: aeron_udp_channel_interceptor_init_func_t, outgoing_send_func: aeron_udp_channel_interceptor_outgoing_send_func_t, incoming_func: aeron_udp_channel_interceptor_incoming_func_t, outgoing_close_func: aeron_udp_channel_interceptor_close_func_t, incoming_close_func: aeron_udp_channel_interceptor_close_func_t, outgoing_transport_notification_func: aeron_udp_channel_interceptor_transport_notification_func_t, incoming_transport_notification_func: aeron_udp_channel_interceptor_transport_notification_func_t, outgoing_publication_notification_func: aeron_udp_channel_interceptor_publication_notification_func_t, incoming_publication_notification_func: aeron_udp_channel_interceptor_publication_notification_func_t, outgoing_image_notification_func: aeron_udp_channel_interceptor_image_notification_func_t, incoming_image_notification_func: aeron_udp_channel_interceptor_image_notification_func_t, meta_info: aeron_udp_channel_interceptor_bindings_stct_interceptor_meta_info_fields, ) -> Result<Self, AeronCError>
Sourcepub fn new_zeroed_on_heap() -> Self
pub fn new_zeroed_on_heap() -> Self
creates zeroed struct where the underlying c struct is on the heap
Sourcepub fn new_zeroed_on_stack() -> Self
pub fn new_zeroed_on_stack() -> Self
creates zeroed struct where the underlying c struct is on the stack (Use with care)
pub fn outgoing_init_func(&self) -> aeron_udp_channel_interceptor_init_func_t
pub fn incoming_init_func(&self) -> aeron_udp_channel_interceptor_init_func_t
pub fn outgoing_send_func( &self, ) -> aeron_udp_channel_interceptor_outgoing_send_func_t
pub fn incoming_func(&self) -> aeron_udp_channel_interceptor_incoming_func_t
pub fn outgoing_close_func(&self) -> aeron_udp_channel_interceptor_close_func_t
pub fn incoming_close_func(&self) -> aeron_udp_channel_interceptor_close_func_t
pub fn outgoing_transport_notification_func( &self, ) -> aeron_udp_channel_interceptor_transport_notification_func_t
pub fn incoming_transport_notification_func( &self, ) -> aeron_udp_channel_interceptor_transport_notification_func_t
pub fn outgoing_publication_notification_func( &self, ) -> aeron_udp_channel_interceptor_publication_notification_func_t
pub fn incoming_publication_notification_func( &self, ) -> aeron_udp_channel_interceptor_publication_notification_func_t
pub fn outgoing_image_notification_func( &self, ) -> aeron_udp_channel_interceptor_image_notification_func_t
pub fn incoming_image_notification_func( &self, ) -> aeron_udp_channel_interceptor_image_notification_func_t
pub fn meta_info( &self, ) -> aeron_udp_channel_interceptor_bindings_stct_interceptor_meta_info_fields
pub fn load(&self, interceptors: &CStr) -> AeronUdpChannelInterceptorBindings
pub fn get_inner(&self) -> *mut aeron_udp_channel_interceptor_bindings_t
Sourcepub unsafe fn get_inner_mut(
&self,
) -> &mut aeron_udp_channel_interceptor_bindings_t
pub unsafe fn get_inner_mut( &self, ) -> &mut aeron_udp_channel_interceptor_bindings_t
Mutable access to the underlying C struct, minted from &self: nothing
prevents two live &mut at once, so the caller must ensure exclusive
access for the lifetime of the returned reference.
Safety
No other reference (& or &mut) to the underlying struct may be
alive while the returned &mut is in use.
pub fn get_inner_ref(&self) -> &aeron_udp_channel_interceptor_bindings_t
Sourceimpl AeronUdpChannelInterceptorBindings
impl AeronUdpChannelInterceptorBindings
Sourcepub fn clone_struct(&self) -> Self
pub fn clone_struct(&self) -> Self
Regular clone just increases the reference count of underlying count.
clone_struct shallow copies the content of the underlying struct on heap.
NOTE: if the struct has references to other structs these will not be copied
Must be only used on structs which has no init/clean up methods. So its dangerous to use with Aeron/AeronContext/AeronPublication/AeronSubscription More intended for AeronArchiveRecordingDescriptor (note strings will not work as its a shallow copy)