pub struct AeronUdpDestinationEntry { /* private fields */ }Implementations
Sourceimpl AeronUdpDestinationEntry
impl AeronUdpDestinationEntry
pub fn new( padding_before: [u8; 64], time_of_last_activity_ns: i64, destination_timeout_ns: i64, receiver_id: i64, registration_id: i64, is_receiver_id_valid: bool, uri: &AeronUri, addr: SockaddrStorage, padding_after: [u8; 64], ) -> Result<Self, AeronCError>
Sourcepub fn new_zeroed_on_heap() -> Self
pub fn new_zeroed_on_heap() -> Self
creates zeroed struct where the underlying c struct is on the heap
Sourcepub fn new_zeroed_on_stack() -> Self
pub fn new_zeroed_on_stack() -> Self
creates zeroed struct where the underlying c struct is on the stack (Use with care)
pub fn padding_before(&self) -> [u8; 64]
pub fn time_of_last_activity_ns(&self) -> i64
pub fn destination_timeout_ns(&self) -> i64
pub fn receiver_id(&self) -> i64
pub fn registration_id(&self) -> i64
pub fn is_receiver_id_valid(&self) -> bool
pub fn uri(&self) -> AeronUri
pub fn addr(&self) -> SockaddrStorage
pub fn padding_after(&self) -> [u8; 64]
pub fn get_inner(&self) -> *mut aeron_udp_destination_entry_t
Sourcepub unsafe fn get_inner_mut(&self) -> &mut aeron_udp_destination_entry_t
pub unsafe fn get_inner_mut(&self) -> &mut aeron_udp_destination_entry_t
Mutable access to the underlying C struct, minted from &self: nothing
prevents two live &mut at once, so the caller must ensure exclusive
access for the lifetime of the returned reference.
Safety
No other reference (& or &mut) to the underlying struct may be
alive while the returned &mut is in use.
pub fn get_inner_ref(&self) -> &aeron_udp_destination_entry_t
Sourceimpl AeronUdpDestinationEntry
impl AeronUdpDestinationEntry
Sourcepub fn clone_struct(&self) -> Self
pub fn clone_struct(&self) -> Self
Regular clone just increases the reference count of underlying count.
clone_struct shallow copies the content of the underlying struct on heap.
NOTE: if the struct has references to other structs these will not be copied
Must be only used on structs which has no init/clean up methods. So its dangerous to use with Aeron/AeronContext/AeronPublication/AeronSubscription More intended for AeronArchiveRecordingDescriptor (note strings will not work as its a shallow copy)