pub struct AeronWildcardPortManager { /* private fields */ }Implementations
Sourceimpl AeronWildcardPortManager
impl AeronWildcardPortManager
pub fn new( port_manager: AeronPortManager, port_table: AeronInt64CounterMap, low_port: u16, high_port: u16, next_port: u16, is_sender: bool, is_os_wildcard: bool, ) -> Result<Self, AeronCError>
Sourcepub fn new_zeroed_on_heap() -> Self
pub fn new_zeroed_on_heap() -> Self
creates zeroed struct where the underlying c struct is on the heap
Sourcepub fn new_zeroed_on_stack() -> Self
pub fn new_zeroed_on_stack() -> Self
creates zeroed struct where the underlying c struct is on the stack (Use with care)
pub fn port_manager(&self) -> AeronPortManager
pub fn port_table(&self) -> AeronInt64CounterMap
pub fn low_port(&self) -> u16
pub fn high_port(&self) -> u16
pub fn next_port(&self) -> u16
pub fn is_sender(&self) -> bool
pub fn is_os_wildcard(&self) -> bool
pub fn get_managed_port( state: *mut c_void, bind_addr_out: &SockaddrStorage, udp_channel: &AeronUdpChannel, bind_addr: &SockaddrStorage, ) -> Result<i32, AeronCError>
pub fn free_managed_port(state: *mut c_void, bind_addr: &SockaddrStorage)
pub fn init(&self, is_sender: bool) -> Result<i32, AeronCError>
pub fn set_range(&self, low_port: u16, high_port: u16)
pub fn delete(&self)
pub fn get_inner(&self) -> *mut aeron_wildcard_port_manager_t
Sourcepub unsafe fn get_inner_mut(&self) -> &mut aeron_wildcard_port_manager_t
pub unsafe fn get_inner_mut(&self) -> &mut aeron_wildcard_port_manager_t
Mutable access to the underlying C struct, minted from &self: nothing
prevents two live &mut at once, so the caller must ensure exclusive
access for the lifetime of the returned reference.
Safety
No other reference (& or &mut) to the underlying struct may be
alive while the returned &mut is in use.
pub fn get_inner_ref(&self) -> &aeron_wildcard_port_manager_t
Sourceimpl AeronWildcardPortManager
impl AeronWildcardPortManager
Sourcepub fn clone_struct(&self) -> Self
pub fn clone_struct(&self) -> Self
Regular clone just increases the reference count of underlying count.
clone_struct shallow copies the content of the underlying struct on heap.
NOTE: if the struct has references to other structs these will not be copied
Must be only used on structs which has no init/clean up methods. So its dangerous to use with Aeron/AeronContext/AeronPublication/AeronSubscription More intended for AeronArchiveRecordingDescriptor (note strings will not work as its a shallow copy)