EmbeddedMediaDriver

Struct EmbeddedMediaDriver 

pub struct EmbeddedMediaDriver { /* private fields */ }
RAII guard for an embedded media driver launched via AeronDriver::launch_embedded_guard. Signals stop on drop so the driver thread always joins even on panic / early return.

Implementations

Source

impl EmbeddedMediaDriver

pub fn stop(&self)

Signal the driver thread to stop (idempotent; the thread exits on its next idle cycle). Blocks until it joins when consumed by Self::join.

pub fn is_finished(&self) -> bool

Whether the driver thread has finished.

pub fn join(self) -> Result<(), AeronCError>

Signal stop and block until the driver thread joins, returning its result.