AeronCongestionControlStrategyInitialWindowLengthFuncCallback

Trait AeronCongestionControlStrategyInitialWindowLengthFuncCallback 

pub trait AeronCongestionControlStrategyInitialWindowLengthFuncCallback {
    // Required method
    fn handle_aeron_congestion_control_strategy_initial_window_length_func(
        &mut self,
    ) -> i32;
}
(note you must copy any arguments that you use afterwards even those with static lifetimes)

Required Methods

Implementors

Source

impl AeronCongestionControlStrategyInitialWindowLengthFuncCallback for AeronCongestionControlStrategyInitialWindowLengthFuncLogger

Source

impl AeronCongestionControlStrategyInitialWindowLengthFuncCallback for NoHandler

Source

impl<F: FnMut() -> i32> AeronCongestionControlStrategyInitialWindowLengthFuncCallback for F

Any closure with the matching signature is a callback: methods that retain it heap-allocate it into a Handler owned by the registering resource.

Source

impl<T: AeronCongestionControlStrategyInitialWindowLengthFuncCallback> AeronCongestionControlStrategyInitialWindowLengthFuncCallback for Handler<T>

Pass an existing Handler clone anywhere a callback value is expected, e.g. to share one callback instance across several registrations.