AeronCongestionControlStrategyMaxWindowLengthFuncCallback

Trait AeronCongestionControlStrategyMaxWindowLengthFuncCallback 

pub trait AeronCongestionControlStrategyMaxWindowLengthFuncCallback {
    // Required method
    fn handle_aeron_congestion_control_strategy_max_window_length_func(
        &mut self,
    ) -> i32;
}
(note you must copy any arguments that you use afterwards even those with static lifetimes)

Required Methods

Implementors

Source

impl AeronCongestionControlStrategyMaxWindowLengthFuncCallback for AeronCongestionControlStrategyMaxWindowLengthFuncLogger

Source

impl AeronCongestionControlStrategyMaxWindowLengthFuncCallback for NoHandler

Source

impl<F: FnMut() -> i32> AeronCongestionControlStrategyMaxWindowLengthFuncCallback for F

Any closure with the matching signature is a callback: methods that retain it heap-allocate it into a Handler owned by the registering resource.

Source

impl<T: AeronCongestionControlStrategyMaxWindowLengthFuncCallback> AeronCongestionControlStrategyMaxWindowLengthFuncCallback for Handler<T>

Pass an existing Handler clone anywhere a callback value is expected, e.g. to share one callback instance across several registrations.