AeronCongestionControlStrategyRttmFuncCallback

Trait AeronCongestionControlStrategyRttmFuncCallback 

pub trait AeronCongestionControlStrategyRttmFuncCallback {
    // Required method
    fn handle_aeron_congestion_control_strategy_on_rttm_func(
        &mut self,
        now_ns: i64,
        rtt_ns: i64,
        source_address: SockaddrStorage,
    );
}
(note you must copy any arguments that you use afterwards even those with static lifetimes)

Required Methods

fn handle_aeron_congestion_control_strategy_on_rttm_func( &mut self, now_ns: i64, rtt_ns: i64, source_address: SockaddrStorage, )

Implementors

Source

impl AeronCongestionControlStrategyRttmFuncCallback for AeronCongestionControlStrategyRttmFuncLogger

Source

impl AeronCongestionControlStrategyRttmFuncCallback for NoHandler

Source

impl<F: FnMut(i64, i64, SockaddrStorage)> AeronCongestionControlStrategyRttmFuncCallback for F

Any closure with the matching signature is a callback: methods that retain it heap-allocate it into a Handler owned by the registering resource.

Source

impl<T: AeronCongestionControlStrategyRttmFuncCallback> AeronCongestionControlStrategyRttmFuncCallback for Handler<T>

Pass an existing Handler clone anywhere a callback value is expected, e.g. to share one callback instance across several registrations.