AeronCongestionControlStrategyRttmSentFuncCallback

Trait AeronCongestionControlStrategyRttmSentFuncCallback 

pub trait AeronCongestionControlStrategyRttmSentFuncCallback {
    // Required method
    fn handle_aeron_congestion_control_strategy_on_rttm_sent_func(
        &mut self,
        now_ns: i64,
    );
}
(note you must copy any arguments that you use afterwards even those with static lifetimes)

Required Methods

Implementors

Source

impl AeronCongestionControlStrategyRttmSentFuncCallback for AeronCongestionControlStrategyRttmSentFuncLogger

Source

impl AeronCongestionControlStrategyRttmSentFuncCallback for NoHandler

Source

impl<F: FnMut(i64)> AeronCongestionControlStrategyRttmSentFuncCallback for F

Any closure with the matching signature is a callback: methods that retain it heap-allocate it into a Handler owned by the registering resource.

Source

impl<T: AeronCongestionControlStrategyRttmSentFuncCallback> AeronCongestionControlStrategyRttmSentFuncCallback for Handler<T>

Pass an existing Handler clone anywhere a callback value is expected, e.g. to share one callback instance across several registrations.