AeronCongestionControlStrategyShouldMeasureRttFuncCallback

Trait AeronCongestionControlStrategyShouldMeasureRttFuncCallback 

pub trait AeronCongestionControlStrategyShouldMeasureRttFuncCallback {
    // Required method
    fn handle_aeron_congestion_control_strategy_should_measure_rtt_func(
        &mut self,
        now_ns: i64,
    ) -> bool;
}
(note you must copy any arguments that you use afterwards even those with static lifetimes)

Required Methods

Implementors

Source

impl AeronCongestionControlStrategyShouldMeasureRttFuncCallback for AeronCongestionControlStrategyShouldMeasureRttFuncLogger

Source

impl AeronCongestionControlStrategyShouldMeasureRttFuncCallback for NoHandler

Source

impl<F: FnMut(i64) -> bool> AeronCongestionControlStrategyShouldMeasureRttFuncCallback for F

Any closure with the matching signature is a callback: methods that retain it heap-allocate it into a Handler owned by the registering resource.

Source

impl<T: AeronCongestionControlStrategyShouldMeasureRttFuncCallback> AeronCongestionControlStrategyShouldMeasureRttFuncCallback for Handler<T>

Pass an existing Handler clone anywhere a callback value is expected, e.g. to share one callback instance across several registrations.