AeronDriverTerminationHookFuncCallback

Trait AeronDriverTerminationHookFuncCallback 

pub trait AeronDriverTerminationHookFuncCallback {
    // Required method
    fn handle_aeron_driver_termination_hook_func(&mut self);
}
(note you must copy any arguments that you use afterwards even those with static lifetimes)

Required Methods

Implementors

Source

impl AeronDriverTerminationHookFuncCallback for AeronDriverTerminationHookFuncLogger

Source

impl AeronDriverTerminationHookFuncCallback for NoHandler

Source

impl<F: FnMut()> AeronDriverTerminationHookFuncCallback for F

Any closure with the matching signature is a callback: methods that retain it heap-allocate it into a Handler owned by the registering resource.

Source

impl<T: AeronDriverTerminationHookFuncCallback> AeronDriverTerminationHookFuncCallback for Handler<T>

Pass an existing Handler clone anywhere a callback value is expected, e.g. to share one callback instance across several registrations.