AeronDriverTerminationValidatorFuncCallback

Trait AeronDriverTerminationValidatorFuncCallback 

pub trait AeronDriverTerminationValidatorFuncCallback {
    // Required method
    fn handle_aeron_driver_termination_validator_func(
        &mut self,
        buffer: &mut [u8],
    ) -> bool;
}
(note you must copy any arguments that you use afterwards even those with static lifetimes)

Required Methods

Implementors

Source

impl AeronDriverTerminationValidatorFuncCallback for AeronDriverTerminationValidatorFuncLogger

Source

impl AeronDriverTerminationValidatorFuncCallback for NoHandler

Source

impl<F: FnMut(&mut [u8]) -> bool> AeronDriverTerminationValidatorFuncCallback for F

Any closure with the matching signature is a callback: methods that retain it heap-allocate it into a Handler owned by the registering resource.

Source

impl<T: AeronDriverTerminationValidatorFuncCallback> AeronDriverTerminationValidatorFuncCallback for Handler<T>

Pass an existing Handler clone anywhere a callback value is expected, e.g. to share one callback instance across several registrations.