AeronPortManagerGetManagedPortFuncCallback

Trait AeronPortManagerGetManagedPortFuncCallback 

pub trait AeronPortManagerGetManagedPortFuncCallback {
    // Required method
    fn handle_aeron_port_manager_get_managed_port_func(
        &mut self,
        bind_addr_out: SockaddrStorage,
        udp_channel: AeronUdpChannel,
        bind_addr: SockaddrStorage,
    ) -> c_int;
}
(note you must copy any arguments that you use afterwards even those with static lifetimes)

Required Methods

Implementors

Source

impl AeronPortManagerGetManagedPortFuncCallback for AeronPortManagerGetManagedPortFuncLogger

Source

impl AeronPortManagerGetManagedPortFuncCallback for NoHandler

Source

impl<F: FnMut(SockaddrStorage, AeronUdpChannel, SockaddrStorage) -> c_int> AeronPortManagerGetManagedPortFuncCallback for F

Any closure with the matching signature is a callback: methods that retain it heap-allocate it into a Handler owned by the registering resource.

Source

impl<T: AeronPortManagerGetManagedPortFuncCallback> AeronPortManagerGetManagedPortFuncCallback for Handler<T>

Pass an existing Handler clone anywhere a callback value is expected, e.g. to share one callback instance across several registrations.