AeronQueueDrainFuncCallback

Trait AeronQueueDrainFuncCallback 

pub trait AeronQueueDrainFuncCallback {
    // Required method
    fn handle_aeron_queue_drain_func(&mut self, item: *mut c_void);
}
(note you must copy any arguments that you use afterwards even those with static lifetimes)

Required Methods

Implementors

Source

impl AeronQueueDrainFuncCallback for AeronQueueDrainFuncLogger

Source

impl AeronQueueDrainFuncCallback for NoHandler

Source

impl<F: FnMut(*mut c_void)> AeronQueueDrainFuncCallback for F

Any closure with the matching signature is a callback: methods that retain it heap-allocate it into a Handler owned by the registering resource.

Source

impl<T: AeronQueueDrainFuncCallback> AeronQueueDrainFuncCallback for Handler<T>

Pass an existing Handler clone anywhere a callback value is expected, e.g. to share one callback instance across several registrations.