AeronRetransmitHandlerResendFuncCallback

Trait AeronRetransmitHandlerResendFuncCallback 

pub trait AeronRetransmitHandlerResendFuncCallback {
    // Required method
    fn handle_aeron_retransmit_handler_resend_func(
        &mut self,
        term_id: i32,
        term_offset: i32,
        length: usize,
    ) -> c_int;
}
(note you must copy any arguments that you use afterwards even those with static lifetimes)

Required Methods

fn handle_aeron_retransmit_handler_resend_func( &mut self, term_id: i32, term_offset: i32, length: usize, ) -> c_int

Implementors

Source

impl AeronRetransmitHandlerResendFuncCallback for AeronRetransmitHandlerResendFuncLogger

Source

impl AeronRetransmitHandlerResendFuncCallback for NoHandler

Source

impl<F: FnMut(i32, i32, usize) -> c_int> AeronRetransmitHandlerResendFuncCallback for F

Any closure with the matching signature is a callback: methods that retain it heap-allocate it into a Handler owned by the registering resource.

Source

impl<T: AeronRetransmitHandlerResendFuncCallback> AeronRetransmitHandlerResendFuncCallback for Handler<T>

Pass an existing Handler clone anywhere a callback value is expected, e.g. to share one callback instance across several registrations.