AeronSendChannelLossSupplierFuncCallback

Trait AeronSendChannelLossSupplierFuncCallback 

pub trait AeronSendChannelLossSupplierFuncCallback {
    // Required method
    fn handle_aeron_send_channel_loss_supplier_func(
        &mut self,
        endpoint: *mut aeron_send_channel_endpoint_stct,
    );
}
(note you must copy any arguments that you use afterwards even those with static lifetimes)

Required Methods

Implementors

Source

impl AeronSendChannelLossSupplierFuncCallback for AeronSendChannelLossSupplierFuncLogger

Source

impl AeronSendChannelLossSupplierFuncCallback for NoHandler

Source

impl<F: FnMut(*mut aeron_send_channel_endpoint_stct)> AeronSendChannelLossSupplierFuncCallback for F

Any closure with the matching signature is a callback: methods that retain it heap-allocate it into a Handler owned by the registering resource.

Source

impl<T: AeronSendChannelLossSupplierFuncCallback> AeronSendChannelLossSupplierFuncCallback for Handler<T>

Pass an existing Handler clone anywhere a callback value is expected, e.g. to share one callback instance across several registrations.