AeronTermGapScannerGapDetectedFuncCallback

Trait AeronTermGapScannerGapDetectedFuncCallback 

pub trait AeronTermGapScannerGapDetectedFuncCallback {
    // Required method
    fn handle_aeron_term_gap_scanner_on_gap_detected_func(
        &mut self,
        term_id: i32,
        term_offset: i32,
        length: usize,
    );
}
(note you must copy any arguments that you use afterwards even those with static lifetimes)

Required Methods

fn handle_aeron_term_gap_scanner_on_gap_detected_func( &mut self, term_id: i32, term_offset: i32, length: usize, )

Implementors

Source

impl AeronTermGapScannerGapDetectedFuncCallback for AeronTermGapScannerGapDetectedFuncLogger

Source

impl AeronTermGapScannerGapDetectedFuncCallback for NoHandler

Source

impl<F: FnMut(i32, i32, usize)> AeronTermGapScannerGapDetectedFuncCallback for F

Any closure with the matching signature is a callback: methods that retain it heap-allocate it into a Handler owned by the registering resource.

Source

impl<T: AeronTermGapScannerGapDetectedFuncCallback> AeronTermGapScannerGapDetectedFuncCallback for Handler<T>

Pass an existing Handler clone anywhere a callback value is expected, e.g. to share one callback instance across several registrations.