pub trait AeronCongestionControlStrategyInitialWindowLengthFuncCallback {
// Required method
fn handle_aeron_congestion_control_strategy_initial_window_length_func(
&mut self,
) -> i32;
}Expand description
(note you must copy any arguments that you use afterwards even those with static lifetimes)
Required Methods
fn handle_aeron_congestion_control_strategy_initial_window_length_func( &mut self, ) -> i32
Implementors
impl AeronCongestionControlStrategyInitialWindowLengthFuncCallback for AeronCongestionControlStrategyInitialWindowLengthFuncLogger
impl AeronCongestionControlStrategyInitialWindowLengthFuncCallback for NoHandler
impl<F: FnMut() -> i32> AeronCongestionControlStrategyInitialWindowLengthFuncCallback for F
Any closure with the matching signature is a callback: methods that retain it
heap-allocate it into a Handler owned by the registering resource.
impl<T: AeronCongestionControlStrategyInitialWindowLengthFuncCallback> AeronCongestionControlStrategyInitialWindowLengthFuncCallback for Handler<T>
Pass an existing Handler clone anywhere a callback value is expected, e.g.
to share one callback instance across several registrations.