pub trait AeronQueueDrainFuncCallback {
// Required method
fn handle_aeron_queue_drain_func(&mut self, item: *mut c_void);
}Expand description
(note you must copy any arguments that you use afterwards even those with static lifetimes)
pub trait AeronQueueDrainFuncCallback {
// Required method
fn handle_aeron_queue_drain_func(&mut self, item: *mut c_void);
}(note you must copy any arguments that you use afterwards even those with static lifetimes)